
# q-expansion of newform 261.12.a.e, downloaded from the LMFDB on 03 May 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 261
weight = 12
poly_data = [30797548279705794248704, -9478460460037847384064, 709645914927917694976, 15507015861824716800, -2179155305696991232, -3617975849298944, 2125122050961664, -1439668569088, -951901011680, 532863376, 214206700, -42196, -23517, 0, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[-3360, -3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[362515327923209885271917909488985953304020815852886426679342142062592, -66573136640903568367112448119127487405658595166900145656880033431552, 5952997579415414026319483470046797122997608777272272496692253630464, -71402726746631127100125990175859962893403980678062821350622734336, -17518842669416616988701331513343169022600396251016524002394957824, 390837673099493118659035112238654832698775218251862362509405440, 13716890265744351849484483427818155297074556549332513681439360, -303181066799822915798995279229346983775440645211852051863584, -4550952552600876298845450833279270479780480652853611665600, 93916905219779384261939653545227985714210984813659466476, 674505822206201681077816319295764001447301128148177880, -12927243570549188742886748575537584932294625127428025, -36404151233521557746685615669404636100293077626956, 653649087809798562284543549857497042406658132365], 148505380509633834997235790633197556033093637588307826346269081600], [[-13127588081763826378983733248894443275058504651747708691196420686872576, 2506200170487266078636430984195835960934984002702059934288784278814720, -102955976935651868937086711164135594121316790546186217575877630754816, -4947868507177274234253640074222142816748411365148173595077397899264, 269255583601784588718251546016666535080395562758442961442997242880, 2776423933105087575271458708828968297146518362092352989469544192, -193710327829041907275964652936238335243855425141930571884881920, -405405710766332823227885362284361502361112499346041655088928, 59502640892299715267479132054408882601293409781874246354672, -93989482512473808257563853268928542479370164527549252748, -8247824340442049062276613697527130573850810094969985548, 30930330876256824141560347300328026322754416834458565, 421239856482326615160669185147516368062624491850368, -2187989154779812749004608674328798293380050391497], 148505380509633834997235790633197556033093637588307826346269081600], [[-1881781869111685986721535274282646221198561101625167040675101116727296, 363857819799452901665023961905663739024041969149725842537851941683200, -9142227927053595602083642432790396655968630095177889477572030447616, -703755704604412459136892234826468526158896317095549272436478326784, 27796686471190594571319513067427502007992448069348390029830179840, 279594506238434123184965155466339116805544852431221408937455872, -20441653932549268386338453218502259638351864050622962521176320, 29018916619048381946426359965597816738939988466216738967712, 6325165445661374279124585879072688214050786658632869743152, -36260973725919727018653259998168458449049300706058989908, -880867114871069226953365104988217457602327946243133868, 6908650654017049765793608154652918043211473437528315, 45185519717906655721925619719922758170172983704728, -407329077954636904806052175766052938805941422327], 21215054358519119285319398661885365147584805369758260906609868800], [[-30634084267716478153072492736964720594034576105950847718443578081148928, 5915721173705594705057918364961810646716326050095596943790466490630144, -148541608869546726131570383692374450462144717535057253446553561812992, -13233998907643663250105486758241124436160394206510180841426464333824, 450045578700798790061625015016994010885730271909080891483431551488, 7246786180836011842273468737675199303335049035819009316583816448, -332345158453099204668931759947462161348968425350856666156584000, -908613581244809293579077684189194303257483781768215020891264, 103348811337823086583998548825916956373006324641745213947448, -273839299858207156387702906157122825383982274356307662764, -14466085167384705026339534398043892863606513116443327642, 79157821050783436399902425679165538963066147911525835, 745437844057803735021588737024104992354533900500254, -5320386434930212098554565113994288290474509148903], 74252690254816917498617895316598778016546818794153913173134540800], [[6140844908581695140434871100045017570477808416674546606010983775207424, -1542807461313627737732345741432912806465073484306851451420842423615488, 57175695156823122937134155622354599192633377865882724062984216215552, 2754438058056850491510402177969085038807513644621658957162729277440, -153651241720534528778311417333377595790743088343052661771201432576, -581141134281958376746546182296080066081174663043833025049883392, 113149797652956815705148506220163749496496591295849020553100800, -582642282450671446046865888843387219445977999491086757850208, -35727700620360099028223732613428280100058655285435661090672, 301885581355060901481573662935072167609613796925730247132, 5094401686096827413962711912883883915094084562354285708, -50716988355762505563685690621268181336189848880754465, -267016320967514487947798527302223107919241966854832, 2861154697720722143814391510782398302760171669077], 29701076101926766999447158126639511206618727517661565269253816320], [[-22672803933863285322081742950165447834607251198396566848634557780983808, 7316992074263858108708838671077287366906357242870134543836996877287424, -385596285647123102196115399816286164579344858803322116792649691594752, -13328970830579942853672051623400149136783969262437654051912409155584, 954582232073888480871989326253800793472192828306538612410065538048, 2084911925026894632948582490961360249391291031060633764230677248, -673033284871688409091238475775043393548760808611654954806336000, 3398361601210810183122907475450673265895522875377282666867296, 204493101379196083031093413636882582381729702683227437236848, -1627651166663963499701392346003304392004097244551694890204, -28192538449091054815345553276326323802008471482452478092, 265842742837083547996874886021117913086676223798856385, 1437545680279770047955962749567464306145203230135344, -14742694191937032807399598385227386668786576708853], 148505380509633834997235790633197556033093637588307826346269081600], [[96785130816047666353224442195851094152071706144660854699321513228632064, -16807290367985918523149102173927262701622097208041064481975498282237952, 64880669097469769147221911690695458859377479812062203957058785918976, 49756734768455165882815777335336260877372899890227238043778296215552, -397903109263513026470863781684806301914417366602324757376787835904, -48538253738377649441707766738858034890652352972044556399138040064, 276743828771489856404854470684668879980877028407766195935571200, 21764776961750264614536129986688971157109736730610540741467232, -72833498533466566448874793376594092004108005520891375186864, -4879751985325751873380428970255788562100094985864517286668, 8226247906366455378227847219430234092964873993407809356, 531181693722031845931438876710895086501879723137071245, -333341184757820252264493052989366447892912208009752, -22317948357094468745702783663142669712758410899121], 148505380509633834997235790633197556033093637588307826346269081600], [[41012895165339696073751285973553617822444640139250337832601648306585600, -8160224146079990681792520550457861791705197649448170290477455455879168, 292977157288429951443835638576689015694650601941696726493396689932288, 15041303537835190831422374831568417170777287839733902006388523556864, -823781874044885109091871299068413887393724679213113735329972445696, -4132187940982715160673516452719806740458748690832657124777458944, 597064990067886144020247503957630314809967683112169137049186880, -2248134558101009873957258758844159575457408116605551681760640, -183747491062516766617730678892976328846433968583313967460664, 1316694191450621971049960158302541744800252007814566569740, 25542097358849161843053504061935292232437710460097725946, -226300631302727700019778375375483496506431574997667555, -1310112626832612309325317254066705150421797713920350, 12849571552579775277224341895997322499430462010399], 74252690254816917498617895316598778016546818794153913173134540800], [[-6606972596076298503205479125968547287212045926548950292180664630378496, -1041374963872139239154298240518606883559291099791280547050578373640192, 354585363047061449334836137064251258123681864644248025636256473645056, -7641833643617253932846428359492254150721273930355114740842025043968, -849530575970916392951552492241446467722480426019180222430266921984, 19977588894125865663087843818845214140120983814788169930869639936, 629557961785724182454695424982384847022357703941144587864665600, -13949140441057506025617445621388922101524772862748585734796448, -203802835800157430339460888233733495666411333760447917346064, 4144737084988618056008188534108687113192633102829573602052, 29800780778954392333880803659478640776164302909252668756, -557967634468653226965728809662703245621608692630915655, -1594951449628370676602666658024227681957008796542672, 27840072850544849897319425752041093829022462784179], 148505380509633834997235790633197556033093637588307826346269081600], [[30723180377330893077073512167478534394764674815110219785692902502694912, -3654973525719634151119923503900085460153269770122439997320647332265984, -214815020660650327464482783544039477135540834732830518923886411362304, 16991741682108035791482236074650566452589532429454457375577442017280, 421420947387703357550243120623161939829199341796737571420735401472, -24364744630368591452104937340734464630534126646418351824496358656, -305418842809764833795712413035962296888135280848550216563062720, 14023130427802658230862626103962719078071551607909268239846016, 101024839164946405941548245943001288359468899892311405407624, -3763476855044462107370819975117964507249368823594501686004, -15201400803205405038057227128088740165890442088819581206, 473344901451251675350459723259488960623822119361271805, 834523936464396886259667376857106618993261131314034, -22467269147884166956075366191311685719505449107969], 74252690254816917498617895316598778016546818794153913173134540800], [[-700867419123394082313952531099313282296906793584668586726477131153408, 62691587202933028503500624966527897878031467018345971743286061301760, 6583408182711103520048805169140840615539418653471767206465830428672, -378912870627344882465523796211074630516938031390376469382196262912, -13667989329828000721803004448495807634918646542215296306539868160, 609685199313035377349565284929528793052062712393336467182676736, 9886963151095637001884408121819118057550209086981494094119040, -368779542163447825814072545294581287722669631135914029833824, -3218079353711536606080918244212000954968058512428578425824, 101851757186642904188916581941973777525406387128250537716, 476674929862428106768084641099835151025281417618995616, -13064599839219752067237197401768066400811870546885655, -25855721881573248819035075261925836751828704058956, 629092701858874999359620874088277619587546591299], 1726806750112021337177160356199971581780158576608230538910105600]]

hecke_ring_character_values = None
aps_data = [[0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [-698, -15, -1, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0], [6076, -154, 4, -6, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0], [-28427, -3543, -11, 95, 0, 6, -4, -9, 0, -5, 5, 7, 1, 3], [162300, 7908, -66, -115, 15, 14, 6, 9, 17, 9, 14, 2, -23, 2], [-401122, -27555, 1222, -264, 78, -97, -55, -40, 1, 31, 75, 42, -62, -48], [2129275, 40870, 997, 1890, 112, -42, 88, -59, 34, -101, -25, -33, -49, -45], [-3758868, 34036, 4190, -2950, 127, 118, 22, -274, 6, 134, -324, -48, -176, -496], [20511149, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [45278852, -227917, -23866, -23029, -1305, 1984, -592, 1430, -1492, -3114, -676, -2436, -1128, -680], [34891106, 583154, -40954, -51084, 6504, -3334, -4416, 2596, -8506, -4050, -98, 7332, 3482, -5560], [-14160094, -996029, -11366, 30558, 4144, -13151, 671, 502, -8373, -3075, -2333, 8502, -5846, -3748], [156650339, -2183027, 8241, -125741, 12310, -51132, 5826, -13289, 8146, -6521, -2423, 6971, -5871, 2443], [298314463, -2425601, 147197, 235265, -19625, -7058, -4338, 13179, 21490, 12331, -9571, -34433, 8817, 6543], [944829848, 10424790, 522758, 257033, 35127, 182500, 15830, -30219, 4377, 80617, 116, 14280, -14773, -46900], [-25222060, 22972046, 8200, -739460, 79851, -215724, -34336, -27604, 106592, -3308, 43958, -21878, -22778, 23702], [-546944730, -42741793, 465830, 1788956, 22570, -182779, 58669, 94712, -22547, -2585, -44639, 11820, 12152, 18270], [1555994402, -46725056, 349164, -50298, -67456, -32700, 63954, -77044, 77970, -45240, -35082, 97618, 18774, -1078], [397847208, -29837126, -320184, -2582130, 93152, -118616, 67376, 77848, -36552, -106272, 216904, 84480, 54664, 54496], [2833647282, 1205548, 1849142, 127680, 203864, -499548, -69690, -59492, 249176, -197004, 313848, 91276, -95386, 69156], [7540870331, 66026385, 1909595, 3516939, -345943, 342232, 155784, 466553, 69056, 271333, -209281, -150339, 305879, 109689], [-9131719618, -14218674, 1264868, -3165486, 49139, -1505004, 19510, -72904, -418046, 227728, -319032, 229356, -93160, -132144], [-13415014934, -163236451, 3203712, -1961344, -71074, 303671, 29091, -288592, 686109, 133619, 96403, -485406, 70220, 960536], [9806767586, -202272487, 3770414, -945110, 239132, -3846733, -145843, -131494, 576835, 155453, -1100673, -415102, -584696, -1045696], [1684428222, -367836810, 2197246, 9181544, 16732, 7282342, 222504, 360548, 145300, -612116, -705848, -856160, -1020148, -422896], [40881843024, -226420706, -3271618, 2904636, 1110004, 3799160, 465926, 666158, -1209178, -345950, -62452, 59676, -535532, -329596], [-7373708086, -1695740232, -9723400, -9804888, 1932861, 2479064, 574034, -620212, 278574, -562384, 614212, 468340, 51136, -810712], [7263630650, 519261149, -7882995, -42362476, -113460, 3857147, 967304, -387564, -2239916, -470548, -217686, 1395046, 1577734, -14398], [-22931190946, -1964573054, -10962110, 25304522, -619042, 9576990, -899468, -808926, 1561962, 1150254, 610756, 1014488, -962146, -10880], [-47457564203, -515323386, -36802019, -17114392, 1202804, 17504818, -2902926, 2138493, 6703924, 299655, 6835713, 1616885, 868393, 186529], [-11795510067, -1183896072, -9376511, -149728340, 1465506, -5647672, -463322, 1138117, 1002380, 2761823, 2015887, 336135, -4756133, -5542425], [-204324891038, -801225424, -4134124, 123643590, 3039910, -13022708, -139792, 2781018, -6728448, -304464, -7405538, 144728, 3302464, -6804012], [206066636876, -1772667298, 557114, 66987706, -5325183, -2674964, -155170, -2000618, -4699366, -3013770, 2012438, 8490438, 3631766, 4381194], [-100358629700, 169372596, 115383800, 105013269, -1906309, 4876286, 9363470, 10258749, -420915, 2326449, -157844, 2377856, -5169409, -3965492], [269094771312, -3349450446, -133891140, -15753086, 11379567, -33729102, 5172028, 4790480, -6002024, -9404128, 10649848, 3488048, 2357356, -11987344], [21869828470, -2392446133, -250608460, 38686604, -738870, 22161181, 9045375, -3766612, 656571, 8644481, -8577913, -14327304, -5788560, -10750298], [93831855400, -6099996935, -58144218, 317515511, 1504390, -39587232, -16935828, -5898998, 8572748, 17779094, -7750746, -12318306, -5462134, -152282], [332470831196, -9623390330, 283295546, -82724160, -8459806, -71665180, -10818510, -6016654, 3236474, 10550126, 7811724, -20249428, 12375308, 1220180], [-89428646182, -3717953378, -269233876, 257452664, 12734668, -14646206, 21513854, 21070708, -6930758, 18020786, -23146074, -24079716, -4779016, -31806496], [-50560821560, 8765862658, -267841860, 176129814, 6448968, -50232992, -23500028, 20394996, 15176272, -33182540, 9447464, -12755728, -1223060, 3258568], [620782175114, -18588484511, 378646209, -508445890, -20816786, -19963773, 1347602, -12422558, 587800, -14177576, -10407930, -11077660, 10789946, 25714080], [1630821193369, -38079244, -304045977, -607385446, -11030136, 29535864, 38231936, -213365, -30089102, -19495963, -11718601, 7402123, -2363309, 6486355], [414920243830, -771716069, 814000880, -1354774032, -13676794, 155250333, 9909329, -48753496, 11835021, 10058191, -2696865, 901622, -3368662, 1492172], [570302758390, -22150624, -252720996, 461519348, -17478236, -292134464, -21069900, -9509120, -46638768, 5776292, -1508692, 18486864, 19139468, -3714064], [388928786244, 11548732850, 78216264, -305564930, 9180321, 69688018, -31358168, 3542784, -64239956, -61846252, 14392544, 29261124, -27012784, 5811732], [1325520471822, 20901644739, -321587742, 382009005, 9878082, -72547234, 47372874, 28576778, 53924966, 5565982, 71093410, 1294534, -35453418, -17580438], [-654821889334, 12549025194, -1277420028, -403589744, -105137724, -181440544, -29381118, 1670924, 114662550, 123399388, -16419266, -85126626, 100638862, 121938246], [-330614211570, 14241540234, -303278900, -1329190764, 47106682, -189466280, -2103610, 41801724, 88888882, 44492320, -64628742, -45444370, -20894842, 5093870], [3214982604886, 61971816227, 119290418, -395650862, -78475620, -225333771, -56386511, 58704950, -144996667, -22854901, 44880055, 41634420, 84360636, 19129290], [-937045523660, -5870581549, -846419382, -761735757, -116297989, -351849321, 44770833, -37158885, 90775380, 36466902, 29142003, -133087286, 65371101, 91912764], [-1980374233938, 94843942780, -1812873624, 1750663190, 80656689, -501809894, -39145094, -57574304, -9653550, 166747220, 71280034, 59813710, -67062814, -2227386], [-1055227544612, 63893617547, -3248519506, 3202584435, -41218993, -44247273, 139633291, 73375071, 10285310, -82523520, 37082287, 101576088, -57526313, -102663614], [334712065702, -7386552505, -2844751506, -2099086991, -39984800, -206359410, -55314266, 59010302, 143154054, -137106034, 44928546, -255442166, -18176890, 98456894], [4256710087970, -4923968374, -3253085151, 3607277298, 95969636, -341412254, -62383877, 14572214, -133831551, -80855469, -246431013, 260104812, 24107510, -2990318], [2087578015226, -23178172337, -1737059610, 2258189507, 116995925, -948145210, 155783874, -202994558, -109634406, -33225178, 189175640, 194964952, -94455568, -247506376], [9956301149846, 43006892951, -2398885944, -795745274, 36932760, -85788595, 254263207, -66556526, 119268931, 342267369, 129213549, -111094444, 148756940, 185473214], [-3066846020332, -60823416405, -5412095376, 7670546543, 368597499, 1135970138, 159994270, -245012552, -55135158, 216031248, 58815886, 280422974, 18631814, 9800758], [-1791462069818, 58253200412, -1390554700, 7548421900, 268023848, 857547436, 102614872, 161719960, -177873260, -177072528, 264074136, 49045616, -24579012, -241157016], [12011017426276, 44310030673, 2262104518, -4383502233, 305242799, -696193007, 43228541, 125918455, 747172516, 274360206, 223160773, -199683596, -154032697, 143442994], [5617710938288, 184773685674, -1562214648, -12320385996, -51565643, -795464148, -292548, -85666284, 185941804, 103851368, 297191010, 72746034, -186852066, 250247670], [10308504554534, -159153937700, 787358318, 1372311946, -201132106, 893999948, 388784058, -42315206, -46490508, 427250996, -493290362, 147052760, 430096298, 91747860], [17912876824617, 27341553973, -5025965673, -1545070585, 407695294, -777272696, -389584018, -414646095, -885924278, 93333333, -573170033, 737113889, 78725423, -392804127], [-261825193795, 206106831944, 3294528227, 12416628122, 165310672, -188356828, 366328488, 329306383, 585400406, 1010457293, -418097925, -300063909, -744479137, -94482045], [18656352846570, 63577027462, -5526887585, 10685236722, -100820464, -1744385306, 190755907, -202005222, 726747565, 265706371, 43577377, -345421574, 236794732, 474571628], [-10005899559582, 152708361979, 2509075432, 12700300598, -34583028, -917859699, -595253513, -80180270, 21676263, -906275079, 423826437, -117090420, 199398072, -713048530], [22490063163926, 526575813571, -5083978650, 8124236141, -415349748, -1645914194, -222747914, 1769247446, 702590062, -665987698, 142720682, -689595382, 841892254, 18314334], [25525881027810, -153666390403, 4142783464, -14906645242, 154895988, 803987883, -199606389, 42177554, -799896143, -1341050961, -186165191, 832936230, -551798324, -297744680], [-28558469531740, -307189421062, 2880123368, 11192051318, 2145945696, 3506536036, 700083888, 854958276, -441937476, -179694932, -1237523068, 157015236, -357403416, -1555601076], [-4063361889724, -136940573214, -4528242860, 35534633829, -1244284941, 338926168, 177061230, 354911497, 1684907629, 1562244085, 276344150, -1283120298, 658947993, 1357257542], [2847426011350, -803991784502, -7387827734, -12624995646, -17759426, 2895190634, -1085997930, -249155054, -11137232, 450203300, 570346832, 781274262, -77551332, -111939898], [-7729656953557, 17248073395, -1779396941, 789248549, 1886931977, -647615040, -948213360, -853257615, 803853292, -971017347, 495411751, 120057029, -351153981, -21967047], [46823554977879, 332012190328, 2054431881, -9571359914, 239997926, -3495602920, 825198900, 16085293, -235977298, 877922947, -578543039, 956397941, 581993433, 668350893], [-7538680211962, 805141605365, 7797812849, -11610256550, -1264753766, 306812679, 182005432, 283316274, 18499526, 435167254, 520722214, -1849057074, 521070960, 385931818], [-20545955973421, 76594609918, -13082916027, -7780631962, 2074934744, 6684260618, -116752032, 645520397, 323967014, -367711601, 1356906423, -1171550869, -1617690225, -2735360993], [-13348737529766, 591889392238, 1809317228, -1881745344, 945822035, 6275964090, -1331977666, -1258940896, 1738082422, 964647592, 796751690, -20788414, 572788382, 510671306], [23403220818814, 103807500930, -17735985212, 3666808342, -3109177722, 4580801874, -225962738, 1617235942, 1748669922, 2178233210, -1019857940, -2531181556, 463583080, 1762663292], [-57315069218122, -807231422985, 13010010785, 13210012282, 950984502, 2238108053, -3021748188, 2212272450, -224423910, -2159220270, 1367533904, -926452864, 275159766, 1097187560], [13582737266300, 1043022272689, 3450705764, 44887563341, -87993983, -5902801363, 1567559667, -1206969455, 1061528952, -551654486, -1618652857, -2887651584, 792104449, 2062234738], [-26628802230470, 939025629496, 10128791272, -15346217732, 2685647460, -3176468916, -1696096080, 2373869912, -1626081264, -3470729616, -1606689636, 348433868, 1204266164, -426181292], [27373176395300, 1328627993146, 65871577562, -46730122248, -1736472070, 2652663336, -92225166, 2505082254, 3732623278, 72561838, 3466060820, -1441468424, -298214412, 3410838504], [-99000721751450, -495305012355, -61372231106, 16463513164, -2587006786, -6665311737, 174230535, 872315892, -699667967, -2337555177, -1637666219, -1503598800, 280670398, -659704414], [-121824779951354, -1503059881240, -2178542098, -9812580828, 3581268191, -3035446918, 2627235072, 4132077758, 576845612, 779350286, -833359982, 2159846622, 17380678, -3396238130], [-127050761572246, 2301954791416, 3404666942, 22074438404, -1317793372, -7419635424, -1234460538, -6550167472, 2821685008, 8096248580, -1190743088, 1735892704, 486332474, 1555598184], [77985340259024, 2710057554448, 53722387430, -41582384002, 5243532035, 11682694186, -401036538, 1597148290, -2042934122, -1275310458, 2900772844, 2617580988, -53681836, -8001876052], [-26002064326845, 4311740579574, 25478843617, -29703682542, -738213218, 16135347302, 485770284, -371379503, 2535670162, 3068440363, 963370887, 431191579, -3989765377, -1571523937], [-21442563372370, 1311586313002, 16652758912, -26062263604, 1169054468, 21267785338, -2502341418, -4050537620, 4164528916, -1856631968, 803458640, 1059098128, 2206763230, -2917993544], [-163346901752586, 192773852726, 8884717346, -14097866650, 4133815090, -8541142986, 162588874, -2670076342, -9247482212, -7293720548, 1100997496, 8112585270, 2848277284, -1122155010], [103561847080814, -2257049000562, 74877764702, 101934082958, -681660902, 11478218790, -3366169512, 2538021350, -456430152, -3409639356, 4787324094, 2855938592, 1020724536, 4860040948], [1248636764026, 22704798252, 39322006284, 70310154482, -3268296081, 20776937354, 951481502, 159518440, 90993902, -812421504, -3095057086, -3359481542, -3900982466, -3270282286], [-16838355690075, 1465881008383, -46400229965, -25147269503, -61232318, 3463629504, 5756777190, 2715208429, -4049105094, 1485376069, -735002929, -1689449515, -5409136477, -2082735803], [62751488566110, 3885828831647, -43270705460, -141970040473, 1627809531, -22780134276, 2016049704, -6164496584, -3363844456, 6734849372, -7762985490, 4163487598, 4279766306, 3596948986], [-35216920593426, 4466153427254, -102653210504, 107356719792, -218304629, 10825772502, 427873810, -8778185444, 3709007074, 6483747788, -2378186146, -102992770, 1389310106, 13886534494], [122700272236935, -935745446223, 107193245429, -143096599913, -8947499398, 49136873404, 2242251750, -5669794933, 5853791482, 5884413331, 615271905, -981774093, -3125785971, 9310347547], [136391745235834, -6347280977222, 117347845290, 127682312060, 1849174797, -7841280124, 4781430644, 6388190410, -4658711856, 509460798, 173715424, 644487028, 1679129920, -8511770032], [-61064217963410, 2121257663731, -95423073756, -111124592057, -2135318113, -822073328, -117537792, 9499602184, 851176200, -2316015668, -2346410510, -5115026838, -2996060546, -5009405746], [174099556521048, 5195595543418, 9218057778, 21416592221, 12775278743, 28236385328, -643814152, -10325350519, 1280340375, 6182371883, -4321049452, 7181818362, -3085113507, -9464213306], [-245895442204502, 3266888122606, -73079504791, 150654094464, 6167200470, 27558917770, -725079979, 5923756488, -3777130199, 682496595, -3734012237, 2534197214, 1862961866, -6747937252], [1987635301694, 10315296276120, 102116875534, -176217310464, -20228166206, 24491968300, -2995692140, 6186938370, -5667734644, -3354087422, -11004372762, -4875159582, 4522672862, 5729526706], [-112519152165926, 4794937782104, 72605067300, 50528494122, 11164878834, 52177363880, 5755526820, -886235770, -1310941152, -4776797932, -7849482706, 11155364952, -3760003108, -11530242532], [222162447613870, 2978575979500, -95064202922, 238295128334, 23538295233, -10598688400, 6372463992, 7807065562, -5578449160, 908442110, -1922205828, 4216269696, -4087154024, -21677205196], [-132793998938278, 13080424746084, 177613580750, -257876932502, 353555510, -23258327128, 12193477576, -2607580874, 12119394778, 978345238, 49090302, -5326737630, 1438075264, -3980920442], [-89944744444214, -2203587949615, -225030418254, 471555632247, -11791132424, -44083469902, 3572635794, 12142859522, -1847535918, 11530731114, -12601115362, -19914786, 15638119954, 14134954730], [314409484111430, 13650813663440, 219324240472, 110251699816, -2623457052, -103140960024, -365231772, -18306023228, -7429779098, 6487100726, -782821962, 8747355964, -9753209826, 5812628608], [258380139687144, 1991872110040, -13889597196, -208805140408, 7365757654, -9676516932, -9266164344, 3473432288, 6360718512, 1907045328, 19016184340, 13620650428, -7005483220, 8918531732], [135669729649630, 11877854597345, 183243739314, -29834194372, 1021810214, 37376271675, -6110983351, -9586504564, 12477652119, 22694451241, -15188875159, -4954897766, -8785271744, 11417579436], [-173726097263424, -2922513192090, -60316727770, 24233529418, -2342156079, 22004650744, 9230047350, -20768564466, -3448369506, 17118033526, -9419318714, 9766198382, 11596864778, 3688812666], [-270488349123070, 2829881471016, -445568273509, 492402138830, 8889195884, -28544088636, -14855989231, -9121101326, 16002556207, 322884565, 3451236815, 5335239482, -4346357144, 912910016], [82984781208525, 1937121974181, -207322660865, -120056778145, -15452691967, -51206104698, 12395936926, 17680073113, -2684688062, -31789340571, -15285284501, 1259938365, -4188252197, -25301577643], [-273036785807414, 14697038832813, -245903702296, 213537759384, 3897458270, -122498031837, 626837187, 13983054840, -583806395, -12731878193, 8574605891, -10928375450, -12575081808, 1032919252], [300896266023206, 5530749265249, -123811721188, -162042940675, -7674889135, -52059094612, -3630916440, 5017806496, -14585929468, -21734413572, 17215087962, 18609615274, -5721090590, -9896057674], [-559017484418862, 12473625364339, -126457510531, -285071316576, -23518910324, 38992275517, 8051991594, -270023464, -33659457290, 8558819554, -28533682620, -11920518950, 732337226, -16585069446], [-275201319226826, 13322295084224, 76526863876, 502249423730, -3746419950, -94846761364, 10692694068, 2661900930, -7639669568, 4365497044, -12388628938, -16282666524, -3498987248, 14662114632], [-309309078916, 2841870473663, -140752280536, 101863045469, -39127227440, -95737657426, 14231557926, -19410516540, -12505874350, 53315457816, -36158122132, -14206611196, -290568304, -145244064], [-37052699880142, -4019955859710, -236596922852, 18313257532, 1070189364, -83299453876, -32260020874, 26289428152, -11990807206, -50310482260, 22676138794, -8935112354, 7697605630, -33491564314], [660375135470382, 9519818583269, 120535494482, -15586506748, 2231829874, 40503796099, -14599541867, 10360929024, -50255964291, -17026909733, -1360759413, -2103425130, 6506853782, -867232804], [397807715904318, -10307311727380, -82302380262, 159846775230, 17320951795, 138250621796, 5827608136, -13469394114, 16560369044, -15099954514, 51935956236, 19064771692, -6324953288, 5758123912], [-256896205258560, -2695007027168, 266725090698, -169397298234, -24153072249, -21819304046, 8474239954, -28669519982, 10736839890, 58496647330, -19649310440, 15985438116, 5130706764, 10138620700], [-100131495124614, 12444257802505, -433485322312, -364505186364, -4496423110, 145082436867, -8333386755, 3964757860, 60483890659, -4792246403, -3611507209, -2874257576, 10866485770, 48939215342], [-212466554188490, 6260645908561, 869167657324, 276656563455, -4720380806, 52104140416, -7499420836, -23370983716, 53145330928, -12057407080, 25478200872, 15328914524, -14485083960, 32914615884], [1859795774109690, -8629581070404, -679463398550, 149558633002, 19325704010, 29502493728, -5195389880, 23831634478, -56440633470, -36451681954, 960221802, 8567577654, -1136641004, -63552067646], [699399773926380, 9237988216239, 12966237670, 32243923623, 19444755099, -44286602621, 19853154277, 10873067923, -58839686708, -48296084262, 10038581283, 14357199502, -3793530947, -34682716952], [222878182388454, 6970731989104, 812367087446, -294976233974, 41507369050, 30750934476, 12253363190, 24853310174, -10743326348, -42242614780, -9935048714, -14902586404, 2730540058, -38564198392], [518491247263822, -15861904390364, -662600955182, 623822936708, 58665248944, -78738218728, -38733045200, -31993075366, -15892075084, 4294703218, 25542169382, 47265888946, -32032209862, -18479379726], [2109445639214642, 16364062404724, 15106809268, -287828203410, 18072617168, 2963275780, -61478001414, -23991380756, 30853220858, -13474024652, 29332228786, -476502302, -11624524666, -2295162886], [-673840235302792, 4059201308546, 82919294074, -1076963520825, -26969578887, 108866611796, 12145071450, -42489651577, -19093073405, -65617569, 14134287800, 1103963992, -27052318111, 14466898996], [192538182988648, 27224772099322, -512418263660, 196222367399, -43825295379, -3130462396, 23884180066, 26455547035, -7344928149, -43206329957, -66165960902, 10538678358, -17077404109, 13561442086], [-1168543442910662, 9124435191374, -119549186860, -303399157444, -107594269308, 221536753500, -17553480702, -21202874560, 24713027174, -22120934788, 3504255686, -45809517230, 26258522042, 97054318042], [2396664906002827, 13716875853944, 468725000513, -1012256420046, -9376995124, -26029963804, 38956008052, 6223309149, -26172605450, 57999117279, -76931039763, 12033289285, 19891159889, -48939748803], [311809808706966, -35550481158272, -384209002334, -401629948332, 133689452356, -81946179364, -17170488562, -27230319284, 60457035850, -35476182030, 36236744938, -2033742352, -35226882492, -9898701172], [-2237667697822282, 30403309432091, -20754188808, 132129435141, -4653833104, 112650410268, -62863217632, 29177154200, -78997525552, -116556127460, 44469334656, 19411134052, 27301325260, -10085729268], [1288832281639375, -36144971042152, -950604326259, 928985940254, 51089493726, -244879576460, 6786033640, -34801969247, 28592921142, -59715404525, 22135937489, -42072113223, 50359230649, 37214844785], [-520616725082007, -73015001089936, -444503709717, 211377037342, -104737799774, -6013315256, 24228154464, 24423324047, 6783306186, 36725256365, -40447697325, -51202753421, 33365208659, 9058143955], [2382069187807682, -38930881710625, 1067716466786, -1069285467036, -40636721598, -213990156107, 19874767393, 54345635656, -3637870169, 71961224893, 13172344871, -8591093796, -15605918106, 83739917962], [2936393043618818, -40256233187070, -310197352130, 1258363416374, -59450525882, 98714005602, 2968043998, -66372985574, 12755202296, 37395639968, -44891181256, 40661836914, 66205701920, 60225777066], [989359213903518, 90165315240327, 120534280268, -2065333178982, -9546059624, -129899924635, 16642595945, 29780546194, 60198634305, 57140905511, -36082295871, -127764192094, 19244448242, -70395116188], [4778487389279762, 37830287813465, -1560607079050, 334203295034, 94528713372, 155407218411, -23957478669, 31845234966, 12134793833, 19219106555, 32656748263, 79957276072, 24435855498, -31647670250], [1847138802571406, -10184459536038, 213811225364, 3343313253168, -21635804600, 54768020736, -60316884090, -26678528000, -50850947786, -107437561744, 41229103474, 54268765874, -43070840410, -14484606374], [2410379477360306, -12859443716823, -1299522239470, 137958899140, -100032095810, 337777290107, 2449669143, -65542980472, -29371423481, 69385562717, -91865996193, -47164340672, 57992742876, 20274070190], [1346248551499146, 43371098651908, -694925666142, 207634199368, -27931919280, 100566318536, -2546101022, 4014305908, 14650268300, -3674639596, 138773775156, 43565745376, 37767540410, 186004781192], [4703691379570060, 24201570219548, -3269071237926, 231913259052, -61477431541, 26758517320, 14185722674, -68689356942, 35417731818, 95472933250, -128502811294, -11372866798, 92493458550, 105557270230], [-4736799034350068, 68512228307294, 605692003992, -540927853739, 676369931, 164406736668, -68691300108, -64681412955, -182894715493, 62391631251, -78780739170, 78797461020, 10958645827, 29528852428], [-1230058133165311, -5405648452138, 540708296293, 204818845700, -30210762220, 134635863922, 176550080146, 141041945429, -18544839944, 76713566463, -127185625063, -51121421699, -54462057931, -55263249167], [-114835409870964, 43068348256133, 791268506592, -1035622186645, -190008330870, -647917593998, -53006907690, 15113203380, 81421426566, 106751755504, 98964599812, -68322585004, -57195968556, 131051532728], [5632884199446718, -27332232246401, -2197317922596, 832887921682, 78086441244, -206596389883, -40641077693, 146890475150, -29291859443, -69601779449, -20394043817, -35066755444, 27873474506, -129879048630], [208433329984167, 132078142345749, -45666712481, 2182073212847, -46408588333, 463576617580, -60995054812, 121053275261, -107717740392, -324158119487, -42974814265, -35793830475, 53718210699, 4863435881], [-2307943430752882, -19078797782290, 1518454180812, -24286245412, 85512103980, 354676326590, -13713049130, -64559625592, -233476531996, -73535976932, -163406857776, 191791840704, 138600532366, -45715753440], [2953658977054522, 11133303838854, 537934124743, -2614303268064, 16559279566, 349866296450, 167710888745, -8083318168, 170423269157, -41434074465, 21105495073, -5060414132, 57615158804, 166818279646], [6753598497047111, -8114765909905, 972118518957, -1441344412723, -81377267710, -391360216668, -28407692898, 25895469459, 170690617714, 106441392279, -16584790683, -155350717589, 10109824821, 197668257555], [5911362865211342, 42807515533162, -1645725705496, 4267627412080, 50777585694, 400295688828, 109603793030, -85632299580, 123107660274, 172401206944, -9749275278, -90662797106, -71490846202, -35506251618], [-1383686362898028, -12409240340710, 1038264593098, 465443944243, 105638374889, 84538575996, -116913644454, -268668759957, -108100700789, -138528296953, 11814992412, 39909276760, -166058558055, -152309366372], [-2368766712536014, -39148551787210, -639440277552, 1419496609116, 95634228784, 802658947550, -87153813006, 182159888516, 177068094414, -204330674162, -12853147978, -86973697504, -50362452892, -242099532300], [-6812950230376326, -19316541092404, -1343597831608, -4058581955188, 121981316683, -109176712012, -96687567342, -69215207280, -157407168702, -58755162112, -52972369600, 94086912548, 54579653828, -170808941320], [-2460981097159096, 61258662904299, 3075205216352, -3078043198097, 219213594391, 435969875966, 176594965334, 30270293832, -95272617238, 178645529492, -188680741058, 172916777650, 105805370394, 10425878946], [4462225597885765, 136053233340854, -2105851296385, -478308089274, 306140747946, 966369875326, -64009101940, 1045258207, 28708842482, 69033475273, 112174054993, 62729011489, -71344034687, -114607907539], [6900673695163900, -28074700902815, -3625698528080, 3286629342889, 304010813821, 732581499426, 37036191450, 53464353920, 19997882454, 147660202136, -38311804306, 19805529046, -95811740306, -170022593706], [1050880723987788, 34002474598410, 1888278354100, 4757571126062, -76145306266, -612716670284, 233624245668, 18428524480, 69993986668, 52944805236, 83411993708, -76448401472, -216302046856, 228644001016], [4978318908512310, 35921100637436, 948039633360, 1667764085000, -240819200676, -623336871532, -6296859640, -59888393868, 398703096356, 142707206808, 305017382584, -248014728244, -209078289488, 345807548932], [6423091767657674, 137013762656924, -256471609602, 7126367305670, 47065400718, -563324978264, -175470318352, 148108226550, -122802591414, -244541131278, -36582109406, -49177071526, 76024705200, 17448192990], [-8644505165905974, 26985644321223, -1552471041941, 3055670127760, -35140148516, 600589603649, -42550719016, 3777403900, -503302205676, -182517135768, -140873012458, 204888132446, 191646331582, -462433701686], [8080209356429361, 102180567775187, -3056867267669, 1501602361265, 117052754808, -265318937756, -156529670986, 89687229349, 30933221134, 6779265725, 360500050135, -78686151891, 2736222847, 43129754277], [131532515599220, -156454893307857, 2435803979724, -71607483971, 77172098117, -439206304545, 138987052183, -100853700943, -52028288344, 514013985274, -415797396991, -4250485226, -41219909833, -172200850652], [-2427408614915263, -143050477362355, -786602718689, -3199378719213, -183486309947, -744806640306, -26150827982, 88993565313, 103595861942, -361403890387, 133133406543, -1732100079, 119798303351, -47010368999], [3190936487771313, -28079064144322, 287536486275, 3594281963830, 128402160350, -923552459354, 27404486976, 412433593435, -78610112610, -159082199367, 74359019861, -164642975911, 159696623745, -10752420155], [-2483815978325882, -202763661127776, 274843642801, -5605193291950, -104670728168, -99562432092, -274463374241, -293454896422, -153852573167, 106859817367, 95071325845, 58895642658, 147935627484, 301822957804], [4219169664118677, -224391508799853, -5015133759529, 3942279544905, -182589011817, -136280335458, -63122063386, -221312089871, 45362217642, 423487266721, 144305088139, 177738993265, -11439296537, 194895075233], [-1624022216577150, -23867334061374, -3950532990202, 3364157308274, 77321031338, -609011535528, -310921948176, -181404708466, 88823927440, -231387427638, 90946872066, 111371604922, 249338149134, 300822875578], [-5162353958090050, 49500765503746, 3994438402748, 10270373579702, -26441329174, -108028241978, -158838912846, -351867907054, 195657095556, 230447061832, -158150251866, -291338729532, 106394516182, -102336076616], [19829015869686114, -109041790390620, -2857043455053, 8061035905950, -417895283532, -2154955793584, -211159614827, -62154914474, -80195926761, -343900043935, -11177095345, -468724465478, 322354435580, 120273874696], [-295101642009986, -115271064553800, -259828305196, -10672265401942, -177036221986, 170547114716, 182387482524, 146825127122, -191366741548, -177212406056, 150817757466, -314230218828, -111847976420, -192915747280], [-1395234008089146, -73262286595256, -179455267530, -7563632184806, -333071535995, -1033066131948, 106013976616, 415717924290, -35424163928, -322234580894, -330819430500, -460467885764, 61935202460, -96220194520], [15839104967257870, 64138083086807, 646003842055, 6903393572050, -829125811322, -1658154695771, -34757610620, -167682356310, 46281531414, 197924473806, -316993315054, -164364480182, 353400299512, 412612935582], [5662009781133980, -341929124241306, -3786601679762, 1810614447104, 493091910046, -1946843905688, -176200869654, -426214033734, 231231120514, 61492846850, -1745734120, 90546812396, -266523608516, -213482321500], [-6020334124844798, 13544694325936, -6687084851056, 6340925122516, 153678596624, 776550335372, 7666535572, -593087624164, -386093087046, -99382304750, -330815491162, 272020900496, -197886287554, -726009180], [8068065484113912, -173246579976420, 6783964011620, -5965338779256, -126171727217, -241281709314, 367411541788, 428826615880, 465177435708, -91994550248, -125982314124, -535676200668, -430798074580, -37398945276], [-4843349259148578, 107637399031782, 2527342164950, -11005012949858, -329812284854, 472809021582, -111299148242, 175641904446, 96681005828, -74982696208, 188112446560, 60614884070, -97763546840, 247052381270], [-545888478165794, -96771090823688, 3637700156546, -91476693380, -747342756826, -736497259340, 461889562212, -481615614402, -265376420784, 744682653542, -196546466086, -120332404746, 176484978014, 599196232462], [-2294186578812458, -144349334293459, 3930950100978, 239647058372, -848565160810, -2608499558977, -354019950553, 206408828668, 182174710711, -358434540543, 100668738995, -6681259684, 514893918032, 842454379786], [-30262450792813221, 269934797058909, 4157592301763, 1855187416387, -95905240703, 3935247252, -182076019120, 147234016505, -181490050252, -121970906623, 193867826415, -1211169287, -101052053257, -558170529755], [-219129918523198, -336584322230738, -6387835054920, 18663178037112, 186657842368, -181818755910, -699940427802, -231939665836, 526861689110, 10071729238, 114731597326, 106999417000, 147762360112, 349221989996], [-24781034676712265, 167253385884813, 4808304184959, -7529839104545, 16610909421, 2307664129296, 138230702520, 348427218309, 160167333012, -59522136843, 547642579215, 171879410017, 221740150871, 664341338101], [8917925408982364, -149229480383217, -3650787384758, 4322721026465, 649336762938, 157548073564, 2583811396, -404341458250, -309557343004, -49811425346, 157027391874, -87300112434, -309230699158, 393589389006], [-10172172246218138, -254813247188468, -1013666420026, -8795901478154, -394127143622, 838118221344, 48647595072, 549439266258, -76142798714, -198289362374, 333297648990, -404827798582, 64890716940, -238916777266], [-3081733276211282, 52877992679610, -5330981109881, 656693168756, -39934835950, -264548055890, 455554751243, -73031266896, 210764384119, 46901446785, -251651638943, 253148589178, -239150960034, 172055740620], [12630794948563278, -141696080885452, -8576951774080, 14523851442890, -360128381620, -2873745731132, 196996832706, -193203276312, 457666196038, 222594031688, -277571120290, 99346197886, 310318751022, 387895306398], [6793072366520586, 2493659085223, -12195864447175, 5311105551976, 54136570368, 399449975945, -140856658106, -1097597843036, 1209604861262, 1376242265902, -320820514592, -669987515722, -95448636742, 753574448582], [-5425462123130810, -88600542960513, 6931379674732, -20777685118066, 306050478256, 453615498837, 479466842239, 673555443866, 273459797653, -45232081137, 504333384479, 361019761288, 226299059594, -450806716474], [4763348856093687, -205772497718142, 7409454352209, -20865857784498, 406606897008, -31151427010, -240932449104, -314590309399, 759439286942, 843709197499, -340849809625, 31635456123, 382533638807, 259843153399], [-9729848995084818, -360779426351679, 3021285057866, 14946413289668, -577068447230, 5972507339519, -115286773491, -246189570276, 708769827457, 12293887027, 127527334835, -228986258166, 114686713902, 410805913160], [24515429053802802, 8808419102334, 3379957486036, 6605024085800, -252640794961, 736259659082, -565242281450, 11934032884, -483692414654, -430687664392, 315852887606, 126411578402, 18695923954, 267737272730], [4009398047678856, 148379819347863, -9179139501434, -8435156024741, 1173154531367, -62212848341, 125671343923, -1279910352869, -424534698490, 140140643940, -287535096597, 1173903308084, -136388675509, -614807095266], [4653967463787478, -566722289730481, 5830120275102, 6569256877081, -245590644396, 938034163934, -461855979054, 444201662342, -259160609446, -634296025206, 268514257690, 493841916222, -375895668502, 635740885458], [12360120470680701, 287232044704469, 2249962328823, 1449782701535, 187354118538, -3787528515100, 87830887058, 167009706009, -385000796598, 396577226033, -342685680477, 178388175417, -68357739117, -593371660135], [10854037352109418, -291304497159804, 8674970029860, 15342005260858, 464268353730, -1636524317172, 831721258712, -550214899954, -370664813226, 1032136527886, -56986834128, 759074173352, -140604143338, -190238473088], [-2843222649857769, 347235032314398, 9937678273297, -11199340253114, 367504433728, -1995384196126, -966984049952, -649338825559, 61187231798, 514434292283, 138527710883, 107063872047, -75628358869, -470954245693], [-8564311510144550, -185540903326722, 4758855697526, 6620155868734, -105933300654, 3365730026894, -103111515214, 606766025902, 311979476248, -164303386572, 227450231256, -104768925110, -338273784156, -217693473110], [7893317714801454, -270631300017918, 14233140502668, 11210932763878, -743356549958, 1214445737062, 541880872958, -31581433442, -784443625602, 193722207898, -290941688048, -506737722496, 1012317816944, 196257908704], [7813271940805762, 296602619667458, -1753562274448, -13127632297352, 308853777892, 4889203546494, -435610169738, 231445134916, -1408865589642, -1419018399258, 1107980903002, 1385435199980, 799046723388, 12621522584], [-1052245273507820, -12318458178299, -3358554186692, 382436002255, -280385010001, 986220984069, 326942234351, -687688665817, 915912116606, 286013698820, 1146423654319, -86933409828, -285896617585, 921509777182], [-20908994621548908, 125710317191940, 2989582293350, -19842770822602, 655042968038, 4310539336964, 119509991422, 294582354646, 546486428718, 1214288327018, 398887591820, -463516437236, -304207172236, 359914324308], [37226395275412334, 379911469864093, 5306923788652, -1909704477736, -118683571166, -1305606040429, -186629135723, 268398924000, 571258958679, 1085700014581, -13988950505, 289890426804, -997937017974, 327032743154], [8797215013263532, 31657398448448, -4965985428826, -23516412064934, -413693218897, -3905939025338, 552882346490, 121810914550, 476042641610, 60726441886, -521982978008, -174869402196, 118201777508, 83064368364], [28635128271611258, -268615532281083, -8651620700286, 9474274951298, -1538072444504, 4211157410355, 891333349391, 562606800558, 279601252025, 641873612239, -1096803684933, -1151410983560, 40444219534, 1197372468342], [-15185351336616938, 1297969693583173, -904690667900, 24351204758332, -7253192162, -5960332951093, -472084571385, -215170896844, -585464961313, 305358304861, 453146875205, 657002866406, 335637930638, -787720865288], [712041457926027, 217159078147590, 4062965308241, 25360672943674, -38705964356, -1232043849854, -586368485808, -1371283914295, -1013758650666, -878218749177, -288176311737, 493291159943, 429061537763, -218490967557], [46927844581343706, 471651661322259, 1287321761789, 17811856029364, 1312186735232, 4916823343933, -444989555626, 184159908072, -320525246634, -1803811240138, 817140875260, 1063441967806, -632229023526, -2426459948858], [87393855461714453, 650504116105695, 12483460135779, -738475013903, 1311571399095, 6055150251014, 1442136595026, -30198212267, -62546275782, 59334731297, -1085947005937, 382333049313, -439234565877, -329063684999], [2497410465161934, 171406749195866, 603240930086, 4905659402766, 919893457784, -4345220696924, 554698897624, 282261056134, -81077839964, -570653471910, 1578511811018, 1862639175290, 1024854545322, 226565636274], [3530193733355474, 4189366076832, -5873545075653, -9018593468930, -2174589038620, 1649563996116, -923311606729, -698283570142, 381172062189, -1340761762505, -647885923249, -740768174648, 389912256746, 889420889254], [16969912360747883, 193997323054617, 6509231629487, -6099502520689, 205683624094, 7026582854054, -1212782403332, 68387058437, -802357839764, -3904471659539, 1470735558003, 1217771487309, 950792549439, -396765549415], [14018751010331442, -198200406023579, 30835486562436, -39667852085232, -1268859165482, 3516135137707, -888048785513, -725079086248, 289428323013, 1609463417911, -1634922282621, -406311317258, 477132133804, 479035979892], [20770619293699202, 229638834788800, -13458901094168, 3675643146612, 127995478992, -2768083932832, 837158681532, -122035753336, -528153410496, -1176364112044, -580990653648, -1309619524524, -1159439741616, -175813816148], [72195801190476434, 749461126185909, -5239478658256, 5519351925537, -1461311268347, -3587001611212, 654663822572, -906995716468, -655585267820, 822257309288, -642907794774, -411186003758, -33521366474, 407975198070], [-22101813878679885, -195194442515491, 3961566584459, -792933396025, -1208028924552, -185806803254, 1586119148012, -46724341607, -1991849078820, 685337457901, -1025580733477, -315828526719, 497616546651, -1358966798163], [28199759924057605, -588519703133712, 1843650993131, 16709262209866, -59224775116, 1956311596276, 1327643374540, 538895170735, -1746461616870, 944538980441, -381584029077, 1062966935359, -347504785173, 252671166903], [36319326100017086, 7352467094754, -1212191622569, 40758768730118, -5354209848, 4812128084554, 289349015533, 236909882626, 923538396731, -377906740127, -491845317187, -54202264056, 44283715482, -1328807759998], [20872621423201452, -618727944298312, 2151018921132, -49069325535520, 1325150030808, 9460167358876, -533376575712, 616798407488, -1311110805104, -690991639204, -1060373130084, 240548619344, 367561564928, 397574995968], [110991965070997886, 247644839846368, 27392145200884, -16539714380014, -1160930903030, -821508947304, 369102458944, -1524839761434, -598332624900, -1158709596648, -2223735400850, 231554521556, 1076346049936, 129670688264], [66852977706972608, 94358339285176, -10085200564070, 7636631749882, 935405863752, 7190804613712, 1450030782058, -764048551814, -6900350442, 883261150526, -867373490460, 533512252076, -1559447974848, 1125574838268], [-37820819132767094, 326444305005232, -19842415609878, -3216619414306, -3192901157922, -4532975350164, 224143237678, -1275124438750, -496698973878, 3018284231318, -2489092395104, -1406674001672, 1665905270132, 2272357754312], [-544788581007898, -1574712348679611, 1672243420832, -51417705103642, -1233206969048, 2974619643427, -615225657391, 1072324375202, 737074283709, 2811909553147, -477658647733, 367043840612, -222990412172, 254742836594], [46064733938211470, -711685195705586, -33630323888658, -3360117927694, -875226227771, 702758416078, -495683545252, 594397285810, -2886882580644, -2342936389682, -270165647166, 1980150303778, 1972636479622, -244798415134], [68572250135968514, 575786991441648, -7644322931808, -56881276542272, 4384260416, 4136379842860, -197466276680, 339083887072, 1820257272296, -1911228493092, 3703227486136, 720202579860, -556050436836, -812854721700], [-11379010132160185, 1472491722437567, -39021328201023, -31605113155803, -2128429927179, 2479235390882, -797122113218, 115399447183, 3012785294886, 1606575617511, 2426820683313, -2246241538989, -1602622792159, 679866299259], [45422026053606444, -186289924155656, 19643992095456, -22191469923068, -877298885382, 649041573076, -963891971564, -4074597070932, -2525686909888, 1337392798968, -1586486893424, 2675014832020, -1184740505752, -1702248884396], [4076448913127594, 131277622178854, 3350338632806, -7699205641090, -1130460078326, -990280921706, 1116853240188, -223899790110, 1417708801482, -307002672698, 2515011268936, 875428383724, 1381070876770, 3098393285436], [-56559260047019506, 1092777706583286, 5912679776354, -55269919521940, 404308975444, -4468216288598, -714525337636, -1267700396588, 1193633155252, -52794603260, 1426202193220, -659363264924, -4105784422060, 1618834554668], [24217948889263087, 903018919862272, -49683057653703, 85028362052774, -821511511564, 12304601190812, -590114796964, 133864997525, -235468336510, -2503630505321, 2314821133141, 36156407533, 1510657264797, -752948001059], [-34614427653308431, 908528430750249, -15169893117789, 8743686332815, 766405621493, 6536892309810, -758406694042, 842647236669, 4290168049770, 2486243317617, 2493497343939, 230789812781, -925678119333, 1180375515709], [-18028055711689306, -394656877519324, -4566779543566, 75844144885374, -2822060985045, -5951741524368, 18121866112, 1183636957278, 1296526271892, 3730592855098, -2615401061540, -3689247687912, 59689153460, 689096821820], [69512954553753038, -555259970788684, 24460964111978, -91564081090596, -4341022045044, 6300932255064, -211906106530, 62365771276, 1594327270986, -748360838246, -1527290979794, -3194385728604, 776717058624, 1018791405000], [55688775910897270, 1210944892923352, 23308170975230, 33542826031288, 1098882609754, 10833625133608, 1566189944296, -3291824832190, -1915880015316, 1068170734622, -1010990182790, -529209705278, -510445876982, 298608918002], [5677481654793835, 299178838528744, 47283297884917, -96248060149374, -937209628002, 3888153881412, -534051621520, -1130988042759, 684663652330, 3960322595, 3100181059289, 76356181881, -1304994964139, 3014514762761], [38707186136143106, -388896749049540, -57953286064502, -42285070660712, 842477312584, -5072322189416, -2874309888994, 3208680963964, 6022092216948, -5062624972772, 5478349388632, -910411995036, 77812363778, 321560630628], [46780398800272886, -971844086420118, -5641408921134, -46130049526382, 220764788502, 10411156916652, -665381778016, -274577236078, -1991386668456, -3488012658918, 895072892630, 2958185989810, -1497525589794, -4721479447958], [199735454185393713, 704243347400694, -3049525263143, 13321009206440, -395029409580, 8042615388146, -276550976930, -2598829484895, -155672984612, 1598491168715, 1594990143041, -1005126291907, -366726709107, -376881369087], [-15024080441257010, -173954770325631, -4365310823002, 15878150924104, 4105125423890, 146715112211, -867682919759, 5109268926576, 2354341417983, -2625443375295, 3553702707793, -2494844733306, 33464307460, -1911530533576], [23548092052380058, -1200174282453045, 3126919705844, 6741805645148, -4670485606338, -21862992448599, -1132824145789, 20356275632, 1869479000531, 1405322603425, -315724280565, 298434671768, 2252565927028, 1807876408126], [-160007947378800584, -712983002525768, -3532874787316, 48440057220590, -758456739761, -5265621990768, -1109423377924, -2645277220600, 4150678589412, 1231962392516, -679079995426, -1040281145634, -301485203270, 697906174066], [95039079199834934, -25877901666745, 5738586256718, 73667478978675, 3054418148739, 21954207726654, -254245827614, 2503219581258, -4361794096934, -741406794822, 1250454797944, 1950548583588, -1306844596732, -4299874868900], [-51151724331077847, -122357483688875, -19401853333837, 8714838998151, 3993098130712, 20367062606352, 493767416054, 2162740346933, -1926088944890, -2461050544911, -2495467378681, 1818520339105, -906144530045, -3921385652063], [59021545790712130, 214874393070758, 26419346228376, -1537435856040, 208560610416, -16981044599720, 2567415350102, 599758592444, -3219865338578, 1458279776560, -7761218458790, -1786732453954, 2336265356434, -473632587498], [-91904116056469010, 304351447344366, -7356166618196, 62483216296684, 3634861530346, -506497856080, -53901273286, -998413021424, -1371295796634, -3466298603084, 5409439273374, 3212960395666, -3819669867966, -2040431478246], [47854308698849774, -353847072996032, -30421506402302, 19790129432936, 4738944357828, -14541361366776, 2988433092898, -3547387577984, -2683352423848, -2414848598504, 542367670732, 356061793136, -4561857586442, -3920814976696], [-117529344660511954, 1439716730680216, 67070946980478, -153885679278182, -1305337099122, -2710338435508, 2656412923740, -901027084874, -140527720330, 3747358227618, -1479751902022, -1854992948406, 1349691167504, 898519554806], [-22385914149321634, -1753602998573778, 51592865976490, -7546992400698, 2122826290334, 11982553486780, -1570386267024, 3003228950750, -3654076577344, -43424634562, -2139222240834, 5582538368562, 1669801074342, 427386012658], [-30795538783262948, -604340421679580, -4847211212320, -32507090759332, 3087073544921, -38417894447810, -3944858104352, -618895968172, 769354761708, 1070994322788, -591946154440, 2397610683080, -967837689564, -1522074295880], [15083596171318018, 1597869544208134, 13857205409916, 121546322600046, 2415157266885, 8602440055928, 3294290768902, -166465614388, 3768841897146, 1203195900080, -1640069094484, 3218120680436, -570427406744, 4809553863568], [82393840425909290, 982947633704742, 23503096968514, -6184268661710, -5260804645378, 22332479714628, 2488338217464, 1710975039666, -1834276811572, -2433156155870, 1708554158782, -407747865278, 2722451678970, 1596352434114], [114715513078583241, 3633018139629623, -18447320260579, -4533153359735, -3312739036219, -12900121899156, 3703527075152, 1209191796431, 3623849957116, -1356661316909, -2192356281743, -4193527441133, 2495071318157, 1162519681759], [123008228003461726, -1149409021167973, 28634624401296, -53568179094254, 694787327112, -16001467936491, 6997231690083, -387372426822, 2373573589741, 5373271217655, -2359243270209, -562901929896, -559257927634, -2038373698090], [27809657040229406, -2594063034127014, 16925661448171, -28481897858090, -1766831995332, 9200503198314, -3120750704855, 2508427385518, -573455884421, 3752473511221, 1622292123989, 1067262053280, -325866639946, -3486837220046], [87150437170870566, 3794971048565897, 77530353909178, -12770480021827, -6000560344683, 4733898688998, 1653547653618, -2730807845938, 2364954145906, 1231634124222, -974504375776, -104987494228, -2202607725868, 5916013649260], [116837047073228454, -327625852636530, -19855918307186, -39014535834136, 33575550480, -619211499706, -2096351321824, 3628732038720, 4675642058884, 821933061088, 2582093336040, -2344536517480, 1576203454620, 3797271965008], [-91380798425557342, 713443447445167, -47672078587088, -25222228317492, 179766298290, -4281377674071, 3308673907883, 3156868299684, -1537364003229, -1949794745887, -5213137022981, -3852744334604, -813289284336, -4196325546326], [-52687590971336424, -2421879299820348, -27186115298558, 39580601059326, 2030090783606, 8034481989008, -3457054843210, 2247976543526, -9682166859090, -12802346311434, 1174677352016, 3240149858116, -1644627110492, -4938979467380], [35728134774699106, 1244570213358271, 88603892753504, 1563170564784, -4557621387442, 20607217886705, 445278033667, 1080999554696, 1433538452073, -5415683836677, 1617983921377, 223461394380, -225131827202, 2954820672606], [90270425617077132, 1238281684591649, 29358640599764, 30426832364331, -2836359794426, 13718366940906, -3346178833150, 3733133446864, -2284277745342, -6504921855812, 2708497952812, 756347023940, -3102606881900, -3158092077848], [-151119487052533558, 3815967707652214, -49747293099376, -101925457504384, 734469043608, -579260345558, 662864728726, -1587675066216, 13540816284490, 1673126535918, 3535199110914, -4066923008696, -242673329164, 1236170510412], [-118529015719023460, -4398755852655479, 18172072065192, 17542049390649, 6536300560713, 9568149052733, 366636740513, -8070367383311, -6093246495298, -2586555754856, -1153261284897, 5666247681602, 1233524342095, -2834567674444], [-240199897734788679, 369371954999744, -55460629762625, 100863682350898, -3333338008276, -14684668847636, 2435624594068, 3284645316467, 1649336667522, -1724265625779, 2488511162295, -4752607057229, 54412813671, -2945746941493], [-72497091756965427, 724552841390367, 83159643807391, -55258208363763, 1679285032480, -2186624800964, 6599220302538, 6286469226113, 3237782770806, 5018596055657, 784067227247, -7293484986083, 1325674033843, 1736428686413], [-9808299913116510, -1037427534386990, 48232583995376, 74911795392720, -2453581152864, 11607104942726, -4904400967886, -3735409951412, -5528830003714, -9003711084834, -142047327450, -2098785689640, 2941494901436, -3719245149844], [31554874783508070, 1592555833468883, -96957191735306, 136936343945824, 1380681620690, -36858943629131, 2181436262901, 9488204575056, 4728284385389, -2013517091401, 6512165743265, -1012382220332, -343695132568, -218922997562], [-94324660919074254, -2033211322750019, -9490317030250, 38049902985940, 4371756195902, 17810867324879, -1781106995367, -8705236249812, 10872767711239, 8287791079201, 4704932361649, 1608658873450, -1127341571632, 9854939947292], [52187804267138113, -5965053140595721, 24073354340865, -29992974426347, -3477836906136, -7150909757066, 4700383879396, 4908381847555, -5004287594280, 3070494827939, -2573085093331, 4226796281531, 255514073869, -438567370057], [96516279501927426, 3052911867537640, 80779843184136, -79378663062946, 699182626582, 18116092092456, 5385985999496, -6757325528594, -7716281258940, 6946197165628, -5310269241506, 4069002890480, 3898724130964, 3514680889612], [-171958129420600754, 3420501499517553, 16211571316068, -16715173709502, 7685946243480, -40292500157577, -1716364163913, 4608399431958, -8559528332223, -12030638681433, 3000851673481, 8888665833586, 3969706649300, -6747407618972], [-44225015822363855, 2411913616601034, -142349665903797, 24441511613870, -3892206318762, -21181895786030, -4613132992748, 3914124877595, 3328330753630, -7614461142007, -1419557517115, -8145494556927, 3955283380197, 717196384525], [-33592367487560190, -135657649754185, 51717279684767, -313088468696604, -3627911083888, 22501432097785, 3795306241656, 3619909264456, 2521773064272, 1749327325580, -92207666534, -3859244316878, -4517316265210, -4264353212170], [213134787475893256, -4446686818277974, -47618177562356, 177636162195309, 5815621413179, -13395252585312, 557784967888, -1347912700179, -690128719425, 194044410863, 980216487454, -4160106711320, -4806870639057, -1990535210552], [139790059633250786, 4867282345134510, 26966178335090, -57311189622974, -3954971970578, -19650984885784, 354417507536, 4268392781794, 8057837436748, -13930444133578, 13507641678230, -1254196699458, -305194838138, 702428581862], [59620940374579032, -3705828053149479, -86676416635044, -100169968822787, 966986929241, 13766571726357, 4027102069385, -6390635681647, 7099182371398, 9680760058564, 435968311167, -3653883243010, 2615160209523, 10670477957704], [-69088175725396107, -7599927035876738, -10958817227983, -29954238181020, -1255718067040, 32567257319410, -5996518406190, -4928872311735, 98827823152, -2097789540509, 1560098127941, 5284125666113, -4825236692103, 5698643809621], [-16836942398341954, -1715017700219186, 62290045276624, -155774098120398, -4217963557570, -50371883742430, -3889553814646, 792252460986, 7182803271778, 9023526778270, -5461660223012, -2730159578124, -5311128254572, 2350498029196], [132782088950776328, 2300101627478497, -99869973967584, 208036120069913, -8671810221981, 15060754018994, 7526053319358, 5471807804880, -4751512235610, 14328461148324, -4318239525566, -2993057924650, 444847818842, -3333973431850], [-278247284634450601, 2447569461659826, -69384376935431, -51753792126074, -4850494350952, -1605452108786, -3738076042528, 5435226408505, 2629579302722, 1723555322703, 5299622245635, -6029639123693, -124557433821, 4786330165303], [-50049754778281598, 28387831180843, -166608003298851, 246919145510782, 1476548960174, -15610566501999, 462160254138, -5069942996758, -4905908605008, 9717494162232, -12367970673332, 4380381624750, 2364754353600, 3083512629054], [40203300157423510, 5350175141285118, -33645546997464, 51730924730094, 4921648757158, -44232523539162, -5621290489806, -4942237893202, -7485188402188, -10706185590416, 1789965069310, 10492550112680, 7472847129874, 3417430118572], [-411886356032917852, -4836910770407862, -3383630487402, 104655947144934, -14114946224591, 6718082114960, 8922949077474, -8959403671778, -5614172540478, 15576829073946, -12425821335282, 4645728063346, 8722084352654, 13684139724366], [186346147344584466, -4902066670756794, 69875041921460, -45282497042540, 6793741665580, -26086039940376, 1060238868330, -3589339254220, 3526528740446, 11002509567828, 4695739498878, -5555733336930, -10993994482002, -841435136762], [-198426065071625460, 1945454628743394, 202580528441224, -35733960212386, -11613635280004, 38956454837992, 6886345647452, -6856059716844, 606301801100, 8535656258032, -9006688400632, -10107453121956, 1531886578100, 4785938088980], [46328105601554440, 1130069719298772, 30680131286942, -85703315865018, 7197435434934, 20877672069896, -5095345902378, 3277449469994, 9742892534, -7139083578086, 11550518573340, 8175237899800, -3924908183864, -17582885909728], [7126651852599674, 1730328628564828, 12978013021142, -187179480492518, 5741976814538, 124760944011704, 1573841536096, -1760152465138, -5114285886458, -10621042315470, -3246955935814, 7214002096458, 7973819890524, -7838987634122], [104036891507169125, 3072569231921728, -153980701334275, 99534018562712, 12363259351198, 11782995779640, -3817857985370, 1371810718033, -6201778447880, -9107535667493, 14767471033675, 457411775195, 6892821358131, -4473747491501], [628332172269559075, -5993140075674732, -36886437224127, 81421930757990, -12003743263850, -60317874751560, -1976595874600, -4366290910035, -2731813299202, 2302599180439, -2424850802591, -7816245194863, 3546472734313, 3686080252289], [-296542321340635122, -7470217854396427, -15340440873032, -129246405479706, -1114200670280, -38340059064913, 499516018475, 1550876910862, -15749583774033, -10107638480839, -7442046846541, 517915298274, 1348916817158, -8648913562536], [229270823250294606, -3017072127714591, 137125880927900, -170427458549132, 5918951484790, -37561962429297, -2027704152635, 4027363644452, -6971832276297, -11616209183155, -7853147045777, 5183914695968, -464876322786, -3704184445362], [-425029381768500422, -177296222795406, 237238588989434, -220845543982682, -11991418588731, -34236565369398, 1379556495016, -736772855942, 8977872111460, -3881468593350, 3129915745506, -4348089554114, -2678286557210, 7923947607702], [-167428220237443136, -12450288850125, -186661959991636, 606216837968795, -13770341977469, 15929019158119, 1827008458293, 2780478529775, -5504871747116, -10190224131086, 204717035553, 4238759256548, 8680586444303, 53100648482], [269731759444025842, 2619382844893965, 282361615386887, -294152336864478, 1241436744546, 37963025385679, 4331145491824, 8117646805450, -2775631516158, -7911366701806, -5569265034760, 276167760072, -3243712192822, -9176668070928], [335995813684849486, -3974290778574746, 68321375462126, -51353236941084, 2567021573509, 32727825225744, 821364698380, 5233646908694, -2687405431352, -6919304603590, 11695531269592, 10751361766348, -5566725534792, -11319424692864], [53662023611244156, -4761751397627869, -175172761452412, 9901998738075, -6332138272881, -46575591502977, -3180188381151, -4850998836181, -3196037571448, -13597120530830, 8573286397041, 4294654033248, -17207771397, 2180843443446], [292896079559654324, -751212656609199, 108613830655510, -8518893676785, -1694585526664, 58530999623584, 8934839979640, 16550060237834, -7957491942272, -7166437844890, -6411807947282, -7110761579010, -3185716019646, -5790804513314], [-133971935938643406, -2199103618239858, -12702750754094, 237715359504594, 20192358320822, 70278349565022, -2764553687544, -5203828131926, -2914397084464, -5176366348332, 12591212475430, 17656404901108, -16644326720068, -4025398948008], [-236527807301846372, 3571064364659728, -41689223342902, -190660645013969, -5144840422595, -7096119876066, -2602753334852, 16758015502795, 8750658882469, -9681863425039, -4428721992130, -17524822928308, 10428057076485, 2908595117212], [-294132805998388273, -3140840641064101, 190377830164351, 48038533474725, 11863949072817, 45300669467056, 1764426329572, 1120940465549, -4302734923920, 4057496409061, 3599310123803, 7580884469541, -1213291660685, -15211127491111], [11787107876029464, -11220592549777062, -100711776967632, -404985164223797, -6665777151043, -30521187181164, 3392239034936, 6644348612571, -8382882894071, 9631516022753, -126257922950, -6773173923624, 1551418736849, -17025436562472], [182996086522284826, 10163617296988740, 146103972373272, 198248485931348, 4369376307049, 59496465784644, 1859436368058, -10950124424272, 387398666082, -11668269420532, 19939498788488, 11078141666584, -60459533272, 20953992048580], [116075192875617137, -6949399606760866, -166805342515097, -133984931087958, 13409228691106, 32591445439814, 6080669331556, -1216928210825, -5333205334222, -8390638966179, 3843412390853, 2799158330345, -4721547025055, 12104993625925], [-157183820748145794, -3579873998383027, -100195395749028, 140664573079218, 9207018959040, 73825878772063, -3508001437673, -1491681680898, -18284881742475, 1973415559207, -377941713007, 24773291663682, -966424720888, -15105488874260], [238694832576627174, -1218156571094172, -59141798267182, -214902462725014, -15620012969150, 10082083854272, -1818878346988, -28911954082, 8386368925326, -8422895284230, -1949227271542, -14550947571462, -1650478767040, -11122361723802], [-158702868468535227, -3442933461954816, 59435769426411, -308511034155822, 15835481858140, -80867270687084, -5884728463896, -12292810409593, -11003152828350, 11602059137713, -6131241278185, 21345722038171, -1308300401349, -9674753752645], [-318046971797731443, -36168431866399, -46076091406379, -18437969478201, 2772468853664, 42339142438918, 2145952511040, 10874497354431, -17032625438852, 3047742213543, -6858295946003, 5530449215531, 1499368459621, -32863897720425], [721023120940202877, -7117215108622062, -45419225051849, -203575848829386, -5738985284062, -92371629321726, 2265489931288, 11808068072871, -12333463608870, 2178155433513, -7143541369207, 3562458468665, -6340712331931, -4385324744731], [-312184236398239902, -2917335056689936, -280023178926643, -91544435810160, -8140010460666, -54462830925344, -14591448777897, 9538197301332, 6441992344691, -13878558963483, 10537107503153, 8546277270354, -9826444675786, -3902628575292], [154674570951322968, -710274509454791, 229810127558508, -410817317892629, 3358041249526, 96138379798246, 2329267369990, 15386540395784, -23139109004754, -6973907629100, 4215922256028, 772567282428, -1766626464268, -1842294145944], [-27158037631465232, 6742109347749846, 72079947640164, -200269509060621, 12571031784317, 112842207422552, -2527620186274, 7527522882991, 11279188545331, 14455090309107, -1864121026834, -13748994654242, -3122907078713, -6932867495498], [-546556072520212196, -5510147026586898, -291045901279738, 624844919453068, -7891057832729, -28037007541586, -1372257282954, -10125973639618, -26292218539726, -34508683734762, 3442660704188, 13575688453328, 2231369407948, -8244152112120], [-107458527304518550, 1287260320919801, 87225184421259, 148124329538848, 10465223685944, -37695479284105, 1030376387086, 1498456363872, 27773582184326, 20771176478162, -4818098827044, -29889752693230, -6815566713538, -14593749493822], [-59325198103727418, -5414045451895220, -472748424479126, 17317728674984, 5185863803023, -8873010161166, -5661387178540, 9814375142834, 19004231599396, 12619625858082, 27323874709858, -9716292050938, -14187663702862, 9237959730446], [-266111131591987086, 929933576765479, -77311746651494, -368921315838218, -6810566617272, -52768183338791, 3995000394521, -12752948930922, -572455522889, 35490991421181, 265235132605, 21153443487416, 2211860865146, -13022014565758], [-719674955352831682, -3676099307168016, 103110463588442, 379644888116558, 26730466025106, 57163862129988, -11522190826684, 5390923974410, 21344247337314, -11505291760698, 24578365042102, 6847293803886, -6223738101872, 12515747469570], [-6920339150805486, 2834689035934450, -54972584110702, 382885529272668, 3150186945175, -70822274894220, 1422215605732, -19818686025494, 11520327077848, 9989901009634, -19280695518328, -6297424794320, 17324486701212, 8100142874500], [330478556304751428, -13086748667046518, -125379526099426, -153854718096764, -4385190894715, -49384819117982, -7019566310162, -1778656520790, -4908797537238, -24534646736218, -2611751457048, -8568304793192, 5637842846804, -6456454224552], [220463760643979952, -12297311818912601, -29391577292866, 84783442092049, -862068097655, 94049502581759, -4341215784629, -5573512178395, 10884607177932, 15100353478230, 31095624253031, 1851046686168, -2515611151259, -3833084984502], [-651729633512254275, -6514835199827074, -202923690424841, 470038515391846, -21258900678630, -67929375824234, 13548374515368, 542471874591, 24878954861554, 14908550536009, -11228830296867, -29147402971459, -5381127986391, 5010358410097], [461459857531579288, 220621826237378, 697072430083136, -221634083985334, -15172918173462, -30039964082336, -4810582198180, 5599794522540, 1593405570092, -8271548333184, -4032549793276, -9076896195736, 8868179641576, 2736466413288], [-12834112440340934, 10096715427740960, 203224813975547, -13784786926506, -30842804804968, -109267580018452, -9454652529511, 20720378730478, 39997101264767, 15985308574185, -5214538040713, -32179124198358, 1804916798160, 14929818403048], [223116977174670, 8701762601951143, 257554185524754, -301128511266436, -12405342691010, -9664795992679, -14793498828389, 15730830744800, -5914905845641, -6010503461639, 14249111480577, -10290984112190, 532370059270, -22661534590236], [698981615489916168, -3810765663244921, 207657052582962, 236920214451481, 16658659815744, 69333211172132, 2208016731076, -15188311920146, 31031931519104, 29097153379150, -14259386547314, -18075579065782, -3206904398054, -2705925794486], [-210236939286076490, -14462300538146214, -188412042828777, -334377638133454, -11137173295780, 12247570438834, -855844223195, 12423128297230, -4287572958613, -15567051816415, 10017110983649, 3118046066632, -6793659769918, -4620451328918], [212223898320332802, -4917927921382176, 176870873138460, -149032470186964, 6507464524256, -32191625348384, 462203135728, -31769110286420, -17815725801868, -4604382413996, -39545010729044, 21190765032188, 3543957736424, 5479908682708], [-268123546669641246, 5997604532854335, -9099215693526, -169963346018845, 7951755249733, 46898338655610, 17490555126626, -13820828105650, -10975902614398, 10451222533326, -24523140739348, 11134334100640, -5316454730304, -27819164239576], [518727372538705536, 5891578602087965, -149996959630282, -8161175197733, 5427194548571, 46864892823437, 4081294830517, 1506644272375, -20365862831144, -28567939889402, -24243576293343, -1262555308912, -11458608531145, -17041099239890], [-96157576432535134, -6352687175295903, 22009125481572, 502998753508920, -16439735790906, -69502538387225, -21876477086937, -28408737297464, -21935119771255, 1996913477891, 8387138772771, 20030710842962, -103129792972, -13466073458976], [146190246963425634, 12099489851586182, -273541795632694, -31592433820310, 5006296267986, 89760572086056, -5450916820532, 1884776546982, 55447907866992, 3497209772598, 33166249444294, -13060648656398, -5078394890374, 37404358673874], [413537659363393180, 3438960877857364, -76035381356194, 148506810900278, -11038118422158, -60179739497296, -18415617364574, 20781795894982, -40445327908350, -17859567558830, -2328723566820, 8672858470556, -10688006826748, -31024073713668], [424020321121470715, -26299802088691693, 264437002141907, 194054853816145, -14147520466259, 17360039288772, 943795225684, 17308329896553, -5684777780236, 8483760013765, 1447202199199, 2932328527557, 30812422832103, 6469736337545], [188273357144292714, -17471744845848811, -53092010234073, 674657454134620, -7197127606304, -130956360370029, 6112972884322, 14407837813544, 23071003739630, 11674850705102, -15007246974892, -44672025417898, -20991995758130, -12221736514418], [192165636737901526, -19194746190985308, 11630832444756, -654014228045374, 36517067890218, -28537123507996, -8380879617784, 21841019756450, -2247075416108, -8487420069148, 29406657096242, 16882564584112, 29314899715828, -24538962184796], [-665549408584279436, -9527504977052582, 245850980528514, 636209256619995, -33873883328211, 134533984673452, 14464611055744, 3790113012247, -10672269972719, 41842945853901, -1795539773652, 7268321483982, -7012921385173, 1374292929762], [-104348122268862876, -561159524051480, 3796005330770, -582130036171470, -41304682721666, -77963259699964, -12043641413398, 12543171145846, 31795471624498, -932188557738, 16216131872864, -16653774957396, 23028693609788, 51934095232988], [-288059826256189783, 934089113866216, 65918650620617, -286947955789968, -15511129280166, 73051723141072, 8812567049758, -17982452065971, -11341189616232, 40025909585727, -52404212336993, -15938405002273, -7083810902553, 20821527285143], [530543819720605709, 36930772352207, -429435292522265, 727325821338737, -17649925526776, -42543020243688, -2723926509590, -7159185087087, -30335896766094, -8229803458307, -30538414806465, -3228269903343, -8517979902805, 6772132323281], [-915026943737938572, -738005610073240, -125858372222384, -644035488671276, 24266182893594, -23896972857864, 14181385558656, -1522879537272, -6338007564660, -6734659953236, 11500450300872, 1008101149980, -9178580303456, 1550285894412], [480997653164576618, -10231090460222096, 216855008099532, -1507225338060144, -8692287087788, 19531504754408, -11053890690604, 18884480441852, -1828139375124, 5898882282600, -20188857173436, -25368074212816, 15130942360360, 17815129120672], [-280709154484401262, 3845249332637976, -308896897882546, 85574457556946, 11529092622214, 37294570182520, -13675119784106, -19939636323262, -34775602940334, -24940795026570, -10237871748144, 31848383912088, 15830099288404, -12503463083752], [8905595907905506, 21731590463769228, 322792140553058, -1196256828745542, -1863956558110, 33543221300952, 21880816649274, -8593991941266, -19216458888440, 9694210467848, -4659533446738, -1407037677344, -23042997332170, 4143895800508], [154573293246726918, -23407909163255860, -182120753235938, 28266918880868, -6367662239162, -11060290916048, 10744221158012, 10673066930674, -17729185595344, 4997122244170, 23248328446074, 4950654568806, -4069932517658, 4830168188646], [212410305339254358, 18259398182323749, 86624030964066, -908671931553852, -9396062673666, 24883202153919, 12828350305831, 20583044794268, -22885723891139, -20316071661285, -22814174750755, -8844534141436, -14179116802890, -40054038221482], [-226243807470244214, 7541428179210838, -540129940107134, 355351635086706, -1243059599102, -9822302591866, 18279052241834, -30305305656718, -23488271586504, 43314752659836, 11053669626832, 41260785100054, -4066250502256, -1071463960890], [-467040124602979702, 3824327020610659, 92120787604698, 326929981757644, -68154596774010, -19310981912419, -14473671737055, -27155133004428, 54552250702757, 8446241809551, 17031700754413, -32269649842124, 7298511314276, 74596448957214], [86743925278992026, -12670928581508204, 497248932950924, 7713276870706, -3594813163796, 81982481753880, -24617436714806, -34205748938480, -4622210515146, 36851510651812, -242956205758, 1187731995310, 1045930191398, -18114096662386], [-1288830673293643386, 15289384606103674, -282794915614964, 379448031899780, 43245780777904, 41551831501006, -12168820314750, 8581057923036, 53159074549706, 24996044411726, 30957065106618, -26539031484044, -38502765206964, -6335497935816], [339285143543032905, -2618395947751875, -747669566723119, 947175116206203, 4988172613370, -44763631840526, -9138282616992, 46450884571443, -18546564244388, -26932867624085, 8597706349217, 20754343065575, 3423404065945, -5431958858317], [508267629641281854, -33112432331492303, 364511613527406, 67251460292980, 31115877748602, 160269145076103, 20626047224679, -20057006866752, -14593340041647, -11453284917545, -5846311785111, 28030759197840, -25115764774082, -7412054187958], [494389038322621915, -1345108754598432, 893552630256359, 48118759100828, 23685586835878, -158504911659672, -16848622423854, -11365079356093, -27055117770564, -15101899147855, 9391146638537, -13513627158503, -1283223927467, -37345789441447], [-2282004412594926265, 2316205625871471, -478179156878213, 1396074851475565, -7768719592301, 50345825113300, -3423775921380, -24481622073255, 44144621514736, 28273961874093, 15655494198107, -25626995679583, -25446654672209, 1149412239669], [863212220149499718, 19851893668124364, 181272408446544, -18309885047984, -23088460961028, 88446011100216, 13244582413796, -18713883674856, -5577024574758, -23484381076742, -4043400432074, 29427146432604, -2363792107406, 24678669567344], [-418432228798943058, -2495818071741810, -267502732492456, -309798803972014, -48676496937815, 217400169871696, 8905104772154, 12269650794500, 32147216281958, 54629090311840, 14302326521124, 2900775571452, 3704776079624, 39404814743712], [-812778711164985970, -2302843982961718, 684531784399946, 683868113238, 51368247164794, 103276872265730, 20130898588882, 23876764692578, 32365466983156, 11825897543772, -17970798680396, -4347493832990, -34367071194616, -57994124733790], [-388629435119653810, -8532759906697844, 398174684205326, 599018893776898, 34786872894618, -130824186131712, -25869497213838, 26028626833102, -23870288678044, -15943907742420, -17868845597266, 38718197420116, 47264937548086, 2325999944960], [-726385599629027756, -39686146309651124, -814124087639144, 255971788984652, 13267957440869, -133963256052198, -32506688592284, -31688837911196, -8149510486280, 2581661537692, 854726029768, -13641516742680, -26927723266212, -10331135343264], [-1723390520877293626, 41749267408560515, -38749452160414, -1038812980189280, -41463986511222, -916502430795, 24399732857357, -23005748863268, -32312258106473, 34392945591193, -7398188100653, 27102616541168, 18641384415654, 1386805255838], [2332772263253770802, -655337722137397, -37840095168064, -554966598192906, -21098639587268, 1161437545445, -2120241753703, 31922708090042, -13018452306611, -2384416881829, 23389432901705, -24491163749626, 10820877141914, 13151339039400], [-133478582341500348, -2288942045785913, 376848276341176, 219145561390379, 26769799799553, 68234687452902, -11205697642810, 61221958869072, -28172653444966, -64976358900208, 25000334288702, 23155839316902, 7806720578214, -6814995248578], [-858522923718433774, 7867756941173756, -490654173164006, -716844911607338, 46276709759763, -97926924089584, 4560895671204, 10470541540494, 16304106282608, -46968690959970, -25748090023044, -21362179384524, 23588603552960, -29193257190040], [-239568095365627438, 7765261209986827, 566008838173194, 1184463282877536, -26679175407722, -275774926386055, 20226662143607, 13737562457264, 17274414371073, 13855939229439, 34319266891547, -25445020637490, -9382054553216, 40430302393508], [-54211824152012338, 22415883047494978, -94140484113008, 681513566799260, 6019550308252, -170985736006288, -19679411026194, -26935934895444, -20744551709546, 8259574830648, -55222719469774, 8072051053134, -4617792999438, -40255564512970], [-2586037931474223078, -13079581774156341, 733634378906197, 587048558472030, -32468327087438, 153741019521, 23466632699934, -14596648356102, 20580027383624, 48766319131720, 8960244744672, -5221664291150, -6242882961936, 54634777770730], [-968149433777968764, 11639307609991617, -269227097637686, -450257960809463, -61917643042511, -1334186766323, -27492498467369, 5102297634189, -14273700047880, 25054417822650, -3294523503483, -27136273763402, -22122188530281, -45319102861204], [1537908754052352301, -24021251752013937, -130249742763099, 349481395137761, -67240186608517, 110865445243932, 7034021630072, 12179690095271, 42453017595544, 37742144998715, -35258489911179, -79278709988801, 18656827846757, 9179469005035], [-1348310211715313712, -17606227744728602, -217168198362014, -436709745515928, -3445101368316, -415304249266668, 22891193788818, 9261832045570, -30333086256930, -15375748749226, 2044023471112, 40765841311032, -4298700008876, -8598340885344], [247515155042572771, 10301002404908503, -289363810013905, -777931743819527, 33704896312920, 59482156752726, 3235774815608, 8943886554741, -8325594203116, 37368448198161, 6873405997023, 46579293902525, -18810921958309, -17476797536999], [-289121160597577086, -17611645439465141, -360214944994190, -448375187497258, -22133771253040, -156361811923927, 1305911645599, 36762948714690, 21482815763719, 31572016499789, -6440227920769, -30014194708482, 18122081400190, -30469286827692], [1276827093523869194, -34582892210473596, -915003356769444, 682372138050786, 14549091998770, -277238963891812, 16581569619492, 18116813729662, 11358536167374, 13800785889806, 21429132648772, 5064035057100, 4965352797150, -4819312499476], [408848625273293746, -3720993729693798, -130085735161842, 848975949392974, 89843501582944, -240518887237968, -16475903330464, -24013512305434, -38139502096016, 84598077710498, 48072424768630, 81542475269558, -44198337121630, -6658947936930], [-2070664026721142598, 5626533360574206, 383282391838944, 1943173275502408, -91195821011440, -113339778757830, -28097451215998, 8499037174756, -14640580448116, -34435310407528, -50252483298204, -39139873725372, 7007956232150, -585711829916], [-3036358328235004260, 13008335450468469, 307684165628448, -936791923320337, -28325467715800, -156809267113918, -4561775874310, -51164064292668, 43338676140082, 86699202958988, -36889945913304, -10603464940, -22942843089716, 9640179673328], [313821294857687984, -17689734665087938, 78487813804156, -435156981732222, -22923583779996, 55178720454424, 38451576861416, 39126145104488, 57092496194748, -39892526508116, 1873937398920, -51619296587828, 25517429108600, 73454529403996], [-2399819656613842228, -33622215623465582, -481298875576182, 1193867085853108, -77186152905157, -397625336913710, 28378457279598, 2399125809082, -20667242381430, 17569502449834, -26318703661460, 40874478529304, 36686784302996, 49487825728040], [541145374088612618, -3348279050251808, 366995821183432, 93786147088376, -36954325098376, -49742199046712, -954232971644, -2512181882948, 65510121570360, 38044525386060, -369946804100, -38866848777700, -40318667930328, 57495819335948], [-374904481692627794, -25451416175170384, -895439920421384, 539378391611286, -65255874594815, -207048501068130, -19215289171590, -88735090294164, 17356163193534, 23798348607988, -38306323381478, 10561316224314, 21923056944834, 49374384667818], [233634336570855606, -42793426499238415, -846552909524837, -305008946929526, -14949283791962, 318243992774971, -9854677988932, -34221279457390, 57357041288010, 37125969521138, -10112747009188, -10021295339900, 11409656159082, 6356198205204], [-140366402656117541, 17308984413089150, 1290402975440885, -1611446935032850, -53282047059210, -1700896197986, 26763369403500, -103160655116691, 654310639822, 34243769681191, -49901871002165, -23531039616073, 37069479604767, 36700837701027], [2035387107116676694, -5326524210535579, 96903705320082, 1439425827727577, -78448516429823, 215234213531734, 7398201019202, -15277706176442, 69256496357742, -3574959285910, 44854671408100, -44487907272884, 16263311863504, 75442139705092], [260088250692769642, -4769223272925853, 1048984276349596, 1184886805222182, -41265719648232, 198989947787517, 52393700094997, 90996664539818, -19884090590425, -4887319197679, -4425289704025, -49134101361074, 26514878426184, 51423693977660], [-126415541925203938, -5024764728053168, -1011596966933135, 724744083588640, 31305433364178, 86833201790400, -26997423748629, -38877034829972, -66263340952489, -10155595511247, -29854891792587, 97389089764058, 34766589924014, -80596053964684], [-857349904236277814, 36860632564227874, 224711250247591, 932441737809262, -45019809430072, -36990431530678, -9580343248481, -61677340563538, 38164396370405, -880304249765, 33033571139117, -44120683993078, -48620476452024, 110790357399028], [-404298320301086122, 39087064325982152, -513797017431184, 149851295678938, -41990517431490, 46494922815932, 31558343635724, 55682877653358, -48265125436506, -103816985217534, 41769862066012, -13634403109400, 2846893411186, 58806961498368], [-1308276292277839026, -1751007278755824, 1109767842470275, 586242454862904, -45113772030546, -13871475121176, 84510705499405, 20856561970596, -44971154467467, -3765138106477, -40308885007437, -33612229175166, 28061275266714, 26854366001992], [-447653839003963473, 88077822771227063, 277150213294591, 953244773869213, 63651417569897, -2459817681860, 58563441770844, -42211610007555, 26408021377036, 30548642320969, -61404100459493, -24659621248887, -58976737927421, -47518935040179], [1392393947674181294, -7868823209891761, 181479820155842, 626690741532924, -72172054807670, 236537706085665, -35543481607245, 26607925701500, 58695688144629, -25464729282945, 34093410341131, -73094822898758, -22634786537620, 91725296723304], [2175187363067836594, 21116185303379796, 76288394207656, -230035690313936, 2329454343681, 88877310823320, -72887299749810, -49555037505248, 80960032833130, 50774862803572, -24295321506144, 19418438359392, -1977470579180, 99559490271996], [1216061952048649778, 20498541071923922, -104415984367106, -2532912876499326, -24235221850777, -223610007141478, 18526742307700, 61356479957042, -194011803506032, -41347111748866, -120968942390070, 39338872647450, 31598202173946, -97766282867950], [1752364168341587727, -24799269730146560, 775740625997905, -468596774505514, -49349981539128, 77999857329932, -24695868066656, 80351435900197, 64138750773234, -107568080665121, 73167565710465, -42746000145743, 21456547982565, 61512619604633], [3209112782153332804, -40585606040884030, 986956335028186, -2283694548721847, -70060277289465, -28138461348192, -5164278292242, 36511367835613, 12700550105957, -8405761259427, -26195066404768, -53654038093176, 8032493767471, 49188347615940], [756529911088809790, -4101992262242543, -164521462298848, 905125727668679, -8198159681862, 80125613282948, 3544864848860, 103102354334584, 152306607739464, -62928423993160, 94647075857188, -90694567464124, -23886985012024, 66729630948540], [2856040773108636365, 49625652726610232, 163364451124575, 319978016192322, 87253295113262, -17852564685620, -66673398013948, 58693010622787, 15137812714294, -120510397597771, 53685420975691, -65289238765369, -6295476931545, -54144777780945], [-228063339674627254, 47321722377900298, -142809155852974, 85644741452494, -114806178244038, 96935684470470, 30429823897256, 48268896190542, -60893799991490, 13629988538370, -54393041209112, -40508791528284, 91147916844914, 22070801620180], [337109099162028072, -39213327982210250, -481106984408852, -1079697635296445, -73864284871047, 345602895371104, 61850132706998, -76944732564901, 71354084498419, 105785392084311, -84281265960594, -36218460898666, 3819517749767, 112170967109430], [54777849268518350, 72074257426641657, 773503546761368, -875185867688837, 27419395365304, 326596164690092, -86609767899632, -1279837167608, -14363220537620, -38286883753028, 23829112496736, 25607458659348, -50923255855560, -43558506838540], [1031225033786752605, 60680249298647909, 996473398309953, -645740150096817, -40050541657992, 68883638720630, -33158489880632, 14922253850387, -73247604555336, -35924121927573, -38823815779175, -23115087868801, 17883855752677, -48491773774253], [783483943638832618, 79318087535674353, -269897276386052, -492657581917523, -114316114646529, -192413410945260, -8106618300856, -52500475925488, 54365144785316, 103351531307040, 56447137255290, -6082763761474, 32314022006830, 86191097103330], [2623018114720919122, 36056130561560802, 56388535494545, -925810899834000, -15244077560290, -303058944313018, 71213552937573, -3853888547004, -48373396141479, 21131093929719, -44472525649185, -17928661258150, -20659116795650, -4186314710008], [1629957257658191966, -5721281904971968, 1248968517295222, 298012016482484, 43275513710564, -36480880592216, -2112003050008, 105726248311238, -110380132070164, -129184185872854, -14843169908530, 14036589967318, 65080015319782, -129934098138730], [-2395073850671576882, 122113524059573446, -344905951765776, 1269416422997158, -22886309033454, 171410637028594, 58186561072534, -10581588913494, 24973090676150, 1951747651750, 29891214641848, 21094122528824, 1351243154952, -26489651374096], [4456980844706410554, -9891227883464426, -286977213157700, 1694772416301284, 15514526939308, -641618334185340, 49497482066118, 53151291991872, -11554830929774, 19435781304056, -45216286339258, 4761265314710, -18710829676210, -54521075794274], [326613349448300594, 46009035304097762, 883922226240404, -890588561714124, -6425484418708, 69262329992778, -68072513805598, -114072797262968, -45425091502828, 38222056927300, 18384247536384, 118466930689328, 21626879841954, 45000431731488], [951887408543978002, -8211927572951498, 342474653851388, -1550416931875752, -31738086005764, 313636747939562, -11585422756882, 16738779178744, -25377818789690, 30424291818018, 54536912493314, -79898315746868, -18731906581916, 18685345968128], [-478156051257927942, 12276747021870610, -504548231987590, 210991728708382, 24109158187426, -358165086755934, -35086357105064, 121804640092550, 100516157643554, -63128312973710, 61718139432460, -137450950934744, -34514539540206, 1477640040888], [-591154935728913679, -7240617716821088, -251866552093261, -1800308442215462, 16950116418134, -256488032431052, -23019276585324, -14733446504905, 11452111103178, 19981936504869, 17042518566203, 109128929746723, -64762140206865, 109015855923587], [1668017156377114184, 4392010864857341, 704057673976570, 579624811870809, -83153438109483, 172237989556225, 37668298204011, 2000268533921, 105466575481636, 31524755921650, -45022674914071, -95327754461282, -69121265760665, 68100056299076], [-2361853253723398408, 750875284635188, -965630356303568, 1048709973313665, 56835132353423, 155255911591838, 18103216984926, 32204922419221, -8928832430075, 28017409834989, 57520896816544, 90079413748640, -61647567699033, -32939578514852], [986567023650684564, 26925917473236976, -223288448430780, -1009532260895636, -87660084138725, 183428286333378, 68899262392992, -177517199110000, -17104158335560, 173159663248576, -123058171883348, -6485219528332, 83165826141316, 79749511313740], [558689315491209822, -7153567939430149, -1334406361185745, -303528411990214, 54907558125662, -84701273705543, 12290674235276, 59820827303498, 141500764212286, -105255101733882, 123921707890918, -163254243123378, -74629956500108, 109956068427322], [1178381178884333698, 17516300565355339, 419077898103482, -657006753999988, 25339360473014, -477892444443087, -39452640796357, 52523737834168, -93888380044769, -106225554587795, -66894390214995, 42515610523426, -12563350906034, -72667270026828], [1103207824824483663, 12134491226518935, 2075118574526535, -717931268498631, 100691437628100, -316061281323886, -41067537493312, 59913827906541, 31508086131124, 15824916588277, 44639280734903, -85538535440927, -26968178296753, -130799474513403], [-889218709285156926, -3651594744244992, 377670066951150, -1769772867020632, 1140991389782, 447016432479952, -42237531206736, 91324463711414, 23345966830556, -43583981261534, 90296252613402, -49831596525326, 131307474196146, -65281563210646], [-45977261374369730, 32580444408434368, -1595484068501142, 178284413581326, -13794983382146, -297287984462996, -62425155051804, 7522266338290, 85077732387430, -140110952746806, 32074209358610, 69123628744478, 72840957432148, 74084112587994], [-2105169443097974304, -5065355484525404, 992994305536272, -736066259456809, -96969363651899, -176023179155062, 27427162308084, 124005191317007, 114925547628077, 14821232910309, 211901190930240, -81458618090382, -1889690167521, 91424478875142], [3040920018763460636, -9512656085464520, 697858335120942, -2389184153190096, -83386250931081, 644073752121172, 35214157760274, -64585470236166, 91358583958522, -35249597286586, -517593272450, -15401764415550, 28824393036918, 102137878165926], [-94226378340169312, 29964141874897202, -726847590293528, 940155381133508, 69140166508863, -109767918840964, -69148666430572, 31580424049984, -57330866235768, 64212083478764, 29418873201542, -13585263544938, 46587928060030, -48574507624078], [-1931574984204912354, 37162906838853729, -348109136099312, -334430374032584, 58502686772494, -364129302329609, -35635609522429, -128347953348716, 46288224332657, 82318157938991, 107677634001939, 57987819089066, -15979200825352, -9058357948288], [3301588074171816302, 31249937704119960, -655498387030618, 502945175241106, 97729763747534, -113102355225416, -37003740022554, -234566427226682, -10690405560526, -18868819170798, 46448888641048, 9966839022232, -56751992120044, -6882669416896], [-1568232135279500446, -1334644854967187, -2511231274892610, 367090691133649, 40166279635667, -860973825215798, 44644783006362, 1772879512450, -36216295795090, -64814990318690, 41278395551200, -81617956098152, -69689183040836, -27452253368224], [1998554185082258828, -12295182330565410, -597023799544548, 3561497899336398, 49085758468320, 21758571848024, -15328776721236, 22414674226324, 38559728059372, 8479671518716, 101435510506544, -27024093249312, 3143208823712, 1323534005616], [2680254597225137490, -1846028559344128, -1032508402527500, 446766413810670, 63499785352730, -1172770703078508, 115878907701604, -67724101879010, -52978769315834, 163431431152230, -107416504934900, -47463827156900, -20104627688666, -84253334399892], [-821153713575733223, -20590886967625481, 863770900348069, -1250572228107903, 73472398690367, -115210470415080, 24635684387600, -33170142124649, 19749040599604, -9816112930109, 69478265752913, -48543988997701, -42309866821155, -65652019178377], [-478016495535694410, -23749271230660932, 866306474456748, 629266310946292, -55773629564496, -442880573609148, 31380601051384, -119249888236744, 125234153018876, 61012695032376, 83160741597936, -70532918585056, 41693665259444, 264276464784680], [-3028894388032699370, -29380044735062266, 726358562446418, -2217923352846626, 29526350298846, -291200303309782, -36849752432040, 26026289729230, -10295280708100, -241645006774092, 78485024596894, 6709503382824, -64254683345436, -40495151136956], [7131925083689542892, -89104672067791167, -1244123775917528, -2808347914843259, 40900968521359, -16477995629054, -8115788217710, 59753299014488, -140024943895234, -32173024467056, -25669470624102, 169859004039850, 45050275778122, -116505933629006], [454933932130142459, 44614323744271295, 943319147668743, -4451794428193043, 60768608470134, 674753632252678, -39488648996108, -5702229091619, -28303103101912, -91524222385307, 27221831275523, 98021068483309, -20488493865229, 11063456196865], [5039585993214771096, -17840621360097601, -520099211691472, 876326110142183, -99491127990601, -829345843098589, 5344092143473, -78140661104401, -63558803183984, 78552143676426, -56887453996571, 19614923186240, 167270096881027, 59193109728702], [1526758924690242394, -23604781653625611, -1205665232966393, 3780128121339992, 23443568721388, -375609698729253, -111863827075938, -14521209627524, 10641840144746, -183466955080574, 79449825781080, -27317556267478, 78531788034234, -1700043583974], [-1784703334425286846, 832808099917762, 3102433028656388, 511901046695834, -22674424990441, 477428637423864, -29733152263842, 120809840517384, -56720075665346, -127179254911732, -57694317134336, -34049476896912, 50337502979960, -225673105919388], [792560899427721034, -52414222746036696, -1289634623995028, -1465132415790382, -5717352521866, 17154375120692, -164783228933056, -77542564384830, -28561292219950, 104868723701746, -62803491983816, 27241439301744, -25948506734398, 89950509853464], [1440172216587587556, 19717403379890666, -193564610034048, -2604516791143852, -162680745843637, -520399697416660, -62942846428612, 155547061294396, -53177462971320, -128228623840384, -79884437824450, -152663984840394, -10359794038842, -25690737852470], [4535200380348843184, -38290356574630221, 1130291194238342, -3181190063453605, -50933708733025, -199775873506508, -85628546043864, -93183317709682, 73426447496660, 26598992602754, 44768365015268, -28610731772520, -52160317533236, 265223235614684]]
